# Mask 遮罩层 Demo

* order: 1

Mask 模拟浮层用于某些选项输入

---

```js
/** @jsx createElement */
import { Input, View, Text, Checkbox, Button, Mask, Page } from 'nuke';
import { createElement, Component, render } from 'rax';
let App = class NukeDemoIndex extends Component {
  constructor() {
    super();
    this.GroupFruit = [
      { value: 'zj', label: '浙江' },
      { value: 'ah', label: '安徽' },
      { value: 'sh', label: '上海' }
    ];
    this.state = {
      fruitChecked: ['ah']
    };
  }
  showMask() {
    this.refs.myMask.show();
  }
  hideMask() {
    this.refs.myMask.hide();
  }
  onChange = value => {
    this.setState({
      fruitChecked: value
    });
  };
  render() {
    return (
      <Page title="Mask">
        <Page.Intro main="浮层中嵌入简易表单操作" />
        <View style={styles.result}>
          {this.state.fruitChecked ? (
            <Text style={styles.resultText}>
              已选择： {this.state.fruitChecked.join(',')}
            </Text>
          ) : null}
        </View>
        <Button type="primary" onPress={e => this.showMask()}>
          打开浮层
        </Button>
        <Mask
          defaultVisible={false}
          ref="myMask"
          animate={true}
          style={styles.mask}
          maskClosable={false}
        >
          <View style={styles.body}>
            <View style={styles.head}>
              <Text style={styles.textHead}>选择区域</Text>
            </View>
            <View style={styles.topicsWrap}>
              <Checkbox.Group
                value={this.state.fruitChecked}
                onChange={this.onChange}
                size="small"
                dataSource={this.GroupFruit}
                style={{ marginRight: 10 }}
              />
            </View>
          </View>
          <View style={styles.footer}>
            <Button
              rect
              block
              style={styles.dlgBtn}
              type="primary"
              size="large"
              onPress={() => this.hideMask()}
            >
              确定
            </Button>
          </View>
        </Mask>
      </Page>
    );
  }
};
const styles = {
  textarea: {
    // position:'absolute'
    width: '600rem',
    height: '200rem',
    borderWidth: '1rem',
    borderStyle: 'solid',
    borderColor: '#cccccc'
  },
  mask: {
    flex: 1,
    backgroundColor: 'rgba(0,0,0,0.7)',
    justifyContent: 'flex-end'
  },

  body: {
    width: '750rem',
    height: '364rem',
    borderRadius: '8rem',
    paddingLeft: 40,
    paddingRight: 40,
    paddingTop: 30,
    borderRadius: '8rem',
    backgroundColor: '#ffffff'
  },
  head: {
    height: 50,
    alignItems: 'center',
    justifyContent: 'center',
    borderBottomColor: '#eeeeee',
    borderBottomStyle: 'solid',
    borderBottomWidth: '1rem'
  },
  textHead: {
    color: '#3d4145',
    fontSize: 32
  },
  topics: {
    padding: '10rem',
    flexDirection: 'row'
  },
  text: {
    fontSize: '28rem',
    padding: '10rem',
    color: '#3089dc',
    borderColor: '#3089dc',
    borderStyle: 'solid',
    borderWidth: '1rem',
    marginRight: '20rem'
  },
  footer: {
    borderTopColor: '#dddddd',
    flexDirection: 'row',
    borderTopStyle: 'solid',
    borderTopWidth: 1,
    alignItems: 'center',
    justifyContent: 'flex-end',
    height: '94rem'
  },
  dlgBtn: {
    flex: 1
  },
  result: {
    height: '480rem',
    margin: '30rem',
    padding: '10rem',
    backgroundColor: '#ffffff',
    justifyContent: 'center',
    alignItems: 'center'
  },
  resultText: {
    fontSize: '28rem'
  }
};
render(<App />);
```
