'use strict';

// ////
// /// @group Utils 工具
// ////

// /// 清除浮动
// ///
// /// @link http://cssmojo.com/latest_new_clearfix_so_far/
// ///
// /// @example.rxscss
// ///   .wrapper {
// ///      @include clearfix;
// ///   }
// ///

// /// pixel转换为rem
// ///
// /// @example.rxscss
// ///   .element {
// ///      @include dp2rem(left, 75px);
// ///   }
// ///
// /// @example css - 输出
// ///   .element {
// ///     left: 2rem;
// ///   }
// function dp2rem(k, v) {
//     #{k}: dp2rem(v);
// }

// /// 单行截取文字，添加『...』结尾
// ///
// /// @param {Number | String} $width [100%] - 最大宽度，CSS长度，包括calc方法定义的表达式
// ///
// /// @example.rxscss - 使用
// ///   .element {
// ///     @include ellipsis;
// ///   }
// ///
// /// @example css - 输出
// ///   .element {
// ///     display: inline-block;
// ///     max-width: 100%;
// ///     overflow: hidden;
// ///     text-overflow: ellipsis;
// ///     white-space: nowrap;
// ///     word-wrap: normal;
// ///   }
// function ellipsis(width: '100%') {
//     return {
//         display: 'inlineBlock';
//         maxWidth: width;
//         overflow: 'hidden';
//         textOverflow: 'ellipsis';
//         whiteSpace: 'nowrap';
//         wordWrap: 'normal';
//     }

// }

// /// 多行截取文字，添加『...』结尾
// ///
// /// @param {Number | String} $line-height [1.2em] - 行高
// /// @param {Number} $line-count [2] - 行数, 超出行数开始截取
// /// @param {Color} $bg-color [#fff] - 文本背景色
// ///
// /// @example.rxscss - 使用
// ///   .element {
// ///     @include multi-line-ellipsis(1.2em, 3, #fff);
// ///   }
// ///
// /// @example css - 输出
// ///   .element {
// ///     overflow: hidden;
// ///     position: relative;
// ///     line-height: 1.2em;
// ///     max-height: 3.6em;
// ///     text-align: justify;
// ///     padding-right: 0em;
// ///   }
// ///
// ///   .element:before {
// ///     content: '...';
// ///     position: absolute;
// ///     right: 0;
// ///     bottom: 0;
// ///     background: #fff;
// ///   }
// ///
// ///   .element:after {
// ///     content: '';
// ///     position: absolute;
// ///     right: 0;
// ///     width: 1em;
// ///     height: 1em;
// ///     margin-top: 0.2em;
// ///     background: #fff;
// ///   }
// function multiLineEllipsis(
//     lineHeight: 1.2em,
//     lineCount: 2,
//     bgColor: #fff
// ) {
//     overflow: hidden;
//     position: relative;
//     lineHeight: lineHeight;
//     maxHeight: lineHeight * lineCount;
//     textAlign: justify;
//     paddingRight: 0em;

//     &:before {
//         content: '...';
//         position: absolute;
//         right: 0;
//         bottom: 0;
//         background: bgColor;
//     }

//     &:after {
//         content: '';
//         position: absolute;
//         right: 0;
//         width: 1em;
//         height: 1em;
//         marginTop: 0.2em;
//         background: bgColor;
//     }
// }

// /// 隐藏文字
// ///
// /// 『text-indent: -9999px』Hack 的替代版本
// ///
// /// @link http://nicolasgallagher.com/another-css-image-replacement-technique
// ///
// /// @example.rxscss
// ///   .element {
// ///      @include hide-text;
// ///      background: url(logo.png);
// ///   }
// ///
// @mixin hideText {
//     font: 0/0 a;
//     textShadow: none;
//     color: transparent;
// }

// /// 将元素垂直(水平)居中 (transform 版本)
// ///
// /// @param {String} $inner-selector ['.inner'] - 直接子选择器名称
// /// @param {Bool} $horizontal [true] - 是否水平居中
// ///
// /// @example.rxscss - 使用
// ///   .element {
// ///      @include center-tl;
// ///   }
// ///
// /// @example css - 输出
// ///   .element {
// ///       position: relative;
// ///   }
// ///
// ///   .element > .inner {
// ///       position: absolute;
// ///       top: 50%;
// ///       left: 50%;
// ///       transform: translate(-50%, -50%);
// ///   }
// ///
// function centerTl(
//     innerSelector: '.inner',
//     horizontal: true
// ) {

//     position: relative;
//     innerSelector: unquote(innerSelector);

//     & > #{innerSelector} {
//         position: absolute;
//         top: 50%;
//         translateVal: translatey(50%);

//         @if horizontal {
//             left: 50%;
//             translateVal: translate(50%, 50%);
//         }

//         transform: translateVal;
//     }

// }

// /// 将元素垂直(水平)居中 (table 版本)
// ///
// /// @param {String} $inner-selector ['.inner'] - 直接子选择器名称
// /// @param {Bool} $horizontal [true] - 是否水平居中
// ///
// /// @example.rxscss - 使用
// ///   .element {
// ///      @include center-td;
// ///   }
// ///
// /// @example css - 输出
// ///   .element {
// ///       text-align: center;
// ///       display: table;
// ///   }
// ///
// ///   .element > .inner {
// ///       display: table-cell;
// ///       vertical-align: middle;
// ///   }
// ///
// function centerTd (
//     innerSelector: '.inner',
//     horizontal: true
// ) {

//     @if horizontal {
//         textAlign: center;
//     }

//     display: table;
//     innerSelector: unquote(innerSelector);

//     & > #{innerSelector} {
//         display: tableCell;
//         verticalAlign: middle;
//     }

// }

// /// 快捷设置元素width,height的方法
// ///
// /// @param {String | List} $size - CSS尺寸长度
// ///
// /// @example.rxscss - 使用
// ///   .element {
// ///     @include size(2em 4em);
// ///   }
// ///
// /// @example css - 输出
// ///   .element {
// ///     width: 2em;
// ///     height: 4em;
// ///   }
// ///
// function size(size) {

//     @if length(size) == 1 {
//         width: size;
//         height: size;
//     } @else if length(size) == 2 {
//         width: nth(size, 1);
//         height: nth(size, 2);
//     }

// }

// /// 快捷设置元素postion的方法 (传入null参数可略过一个方位)
// ///
// /// @param {String} $position [relative]
// ///   CSS position属性值
// ///
// /// @param {List} $coordinates [null null null null]
// ///   上、右、下、左 四个边值，可以传入1 ~ 4个值
// ///
// /// @example.rxscss - 使用
// ///   .element {
// ///     @include position(absolute, 0 null null 10px);
// ///   }
// ///
// /// @example css - 输出
// ///   .element {
// ///     position: absolute;
// ///     left: 10px;
// ///     top: 0;
// ///   }
// ///
// /// @require {function} is-length
// /// @require {function} unpack
// function position(position: relative, coordinates: null null null null) {

//     // 如果参数是数组
//     @if typeOf(position) == list {
//         coordinates: position;
//         position: relative;
//     }

//     coordinates: unpack(coordinates);

//     offsets: (
//         top: nth(coordinates, 1),
//         right: nth(coordinates, 2),
//         bottom: nth(coordinates, 3),
//         left: nth(coordinates, 4)
//     );

//     position: position;

//     @each offset, value in offsets {

//         // 如果是合法长度
//         @if isLength(value) {
//             #{offset}: value;
//         }
//     }
// }


// // 三角型生成器(8种形态)
// //
// // @param {number | list} size
// //   三角形尺寸
// //   传入一个参数，生成等宽高三角形；传入数组且长度为2，第一个设置宽度，第二个设置高度
// //
// // @param {string | list} color
// //   传入一个参数，设置三角形颜色；传入数组且长度为2，第一个设置三角形颜色，第二个设置背景色
// //
// // @param {string} direction
// //   三角形朝向，可传参数：up | down | right | left | upRight | upLeft | downRight | downLeft | insetUp | insetDown | insetLeft | insetRight
// //
// // @example.rxscss  使用
// //   .element {
// //     &:before {
// //       content: " ";
// //       @include triangle(100px 200px, blue, up);
// //     }
// //   }
// //
// // @example css  输出
// //   .example:before {
// //     content: " ";
// //     height: 0;
// //     width: 0;
// //     borderBottom: 200px solid blue;
// //     borderLeft: 50px solid transparent;
// //     borderRight: 50px solid transparent;
// //   }
// //
// function triangle(size, color, direction) {
//     width: nth(size, 1);
//     height: nth(size, length(size));
//     foregroundColor: nth(color, 1);
//     backgroundColor: if(length(color) == 2, nth(color, 2), transparent);
//     height: 0;
//     width: 0;

//     @if (direction == up) or (direction == down) or (direction == right) or (direction == left) {
//         width: width / 2;
//         height: if(length(size) > 1, height, height/2);

//         @if direction == up {
//             borderBottom: height solid foregroundColor;
//             borderLeft: width solid backgroundColor;
//             borderRight: width solid backgroundColor;
//         } @else if direction == right {
//             borderBottom: width solid backgroundColor;
//             borderLeft: height solid foregroundColor;
//             borderTop: width solid backgroundColor;
//         } @else if direction == down {
//             borderLeft: width solid backgroundColor;
//             borderRight: width solid backgroundColor;
//             borderTop: height solid foregroundColor;
//         } @else if direction == left {
//             borderBottom: width solid backgroundColor;
//             borderRight: height solid foregroundColor;
//             borderTop: width solid backgroundColor;
//         }
//     } @else if (direction == upRight) or (direction == upLeft) {
//         borderTop: height solid foregroundColor;

//         @if direction == upRight {
//             borderLeft: width solid backgroundColor;
//         } @else if direction == upLeft {
//             borderRight: width solid backgroundColor;
//         }
//     } @else if (direction == downRight) or (direction == downLeft) {
//         borderBottom: height solid foregroundColor;

//         @if direction == downRight {
//             borderLeft: width solid backgroundColor;
//         } @else if direction == downLeft {
//             borderRight: width solid backgroundColor;
//         }
//     } @else if (direction == insetUp) {
//         borderColor: backgroundColor backgroundColor foregroundColor;
//         borderStyle: solid;
//         borderWidth: height width;
//     } @else if (direction == insetDown) {
//         borderColor: foregroundColor backgroundColor backgroundColor;
//         borderStyle: solid;
//         borderWidth: height width;
//     } @else if (direction == insetRight) {
//         borderColor: backgroundColor backgroundColor backgroundColor foregroundColor;
//         borderStyle: solid;
//         borderWidth: width height;
//     } @else if (direction == insetLeft) {
//         borderColor: backgroundColor foregroundColor backgroundColor backgroundColor;
//         borderStyle: solid;
//         borderWidth: width height;
//     }
// }

// // flex布局的box部分
// function flexbox(vertical: flexStart, horizontal: flexStart) {
//     display: flex;
//     display: WebkitBox;
//     @include justifyContent(horizontal);
//     @include alignItems(vertical);
// }

// // flex布局的内容部分
// function flex(value: 1) {
//     display: block;
//     flex: value;
//     WebkitBoxFlex: value;
// }

// // flex布局的box部分, inline
// function flexboxInline(vertical: flexStart, horizontal: flexStart) {
//     display: inlineFlex;
//     display: WebkitInlineBox;

//     @include justifyContent(horizontal);
//     @include alignItems(vertical);
// }

// //flex布局下, 水平对齐方式
// function justifyContent(value: flexStart){
//     boxPack: value;

//     @if(value == flexStart){
//         boxPack: start;
//     }@else if(value == flexEnd){
//         boxPack: end;
//     }@else if(value == spaceBetween){
//         boxPack: justify;
//     }

//     justifyContent: value;
//     WebkitBoxPack: boxPack;
// }

// //处理flexDirection, 仅支持水平和垂直, 其它值无法匹配
// function flexDirection(value: row){
//     @if(value == column){
//         flexDirection: value;
//         WebkitBoxOrient: vertical;
//     }@else{
//         flexDirection: value;
//         WebkitBoxOrient: horizontal;
//     }
// }

// //flex布局下, 垂直对齐方式
// function alignItems(value: flexStart){
//     boxAlign: value;

//     @if(value == flexStart){
//         boxAlign: start;
//     }@else if(value == flexEnd){
//         boxAlign: end;
//     }

//     alignItems: value;
//     WebkitBoxAlign: boxAlign;
// }


// function transform(t) {
//     WebkitTransform: t;
//     transform: t ;
// }

// function boxPack(p: center) {
//     WebkitBoxPack: p;
// }

// function boxAlign(a: center) {
//     WebkitBoxAlign: a;
// }

// function overflowScroll(d: y) {
//     overflow#{d}: auto;
//     WebkitOverflowScrolling: touch;
// }

// // 快捷方式
// function fontSize(v) {
//     @include dp2rem(fontSize, v);
// }

// function width(v) {
//     @include dp2rem(width, v);
// }

// function height(v) {
//     @include dp2rem(height, v);
// }

// function lineHeight(v) {
//     @include dp2rem(lineHeight, v);
// }

// function minWidth(v) {
//     @include dp2rem(minWidth, v);
// }

// function maxWidth(v) {
//     @include dp2rem(maxWidth, v);
// }

// function minHeight(v) {
//     @include dp2rem(minWidth, v);
// }

// function maxHeight(v) {
//     @include dp2rem(maxWidth, v);
// }

// function top(v) {
//     @include dp2rem(top, v);
// }

// function right(v) {
//     @include dp2rem(right, v);
// }

// function bottom(v) {
//     @include dp2rem(bottom, v);
// }

// function left(v) {
//     @include dp2rem(left, v);
// }

// function paddingTop(v) {
//     @include dp2rem(paddingTop, v);
// }

// function paddingRight(v) {
//     @include dp2rem(paddingRight, v);
// }

// function paddingBottom(v) {
//     @include dp2rem(paddingBottom, v);
// }

// function paddingLeft(v) {
//     @include dp2rem(paddingLeft, v);
// }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function padding() {
    var pt = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    var pr = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : pt;
    var pb = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : pt;
    var pl = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : pr;

    return {
        paddingTop: pt,
        paddingRight: pr,
        paddingBottom: pb,
        paddingLeft: pl
    };
}
function margin() {
    var pt = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    var pr = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : pt;
    var pb = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : pt;
    var pl = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : pr;

    return {
        marginTop: pt,
        marginRight: pr,
        marginBottom: pb,
        marginLeft: pl
    };
}

function border() {
    var width = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
    var style = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'solid';
    var color = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '#ffffff';
    var direction = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

    if (typeof width == 'string' && width.indexOf('px') > -1) {
        width = width.split('px')[0] * 2;
    }
    if (direction) {
        var _ref;

        var x = direction[0].toUpperCase() + direction.slice(1);
        return _ref = {}, _defineProperty(_ref, 'border' + x + 'Width', width), _defineProperty(_ref, 'border' + x + 'Style', style), _defineProperty(_ref, 'border' + x + 'Color', color), _ref;
    } else {
        return {
            borderWidth: width,
            borderStyle: style,
            borderColor: color
        };
    }
}
// function marginTop(v) {
//     @include dp2rem(marginTop, v);
// }

// function marginRight(v) {
//     @include dp2rem(marginRight, v);
// }

// function marginBottom(v) {
//     @include dp2rem(marginBottom, v);
// }

// function marginLeft(v) {
//     @include dp2rem(marginLeft, v);
// }

// function margin(mt: 0, mr: mt, mb: mt, ml: mr) {
//     margin: dp2rem(mt) dp2rem(mr) dp2rem(mb) dp2rem(ml);
// }

// function hairlines(k: border, w: 0.5px, s: solid, c: #c4c6cf) {
//     stripd: stripUnits(w);

//     @if (stripd == 0.5) {
//         #{k}: w * 2 s c;
//         .#{cssPrefix}hairlines & {
//             borderWidth: w;
//         }
//     } @else {
//         #{k}: w s c;
//     }
// }

// function border(w: 0.5px, s: solid, c: #c4c6cf) {
//     @include hairlines(border, w, s, c);
// }

// function borderTop(w: 0.5px, s: solid, c: #c4c6cf) {
//     @include hairlines(borderTop, w, s, c);
// }

// function borderRight(w: 0.5px, s: solid, c: #c4c6cf) {
//     @include hairlines(borderRight, w, s, c);
// }

// function borderBottom(w: 0.5px, s: solid, c: #c4c6cf) {
//     @include hairlines(borderBottom, w, s, c);
// }

// function borderLeft(w: 0.5px, s: solid, c: #c4c6cf) {
//     @include hairlines(borderLeft, w, s, c);
// }

// function borderRadius(v) {
//     @include dp2rem(borderRadius, v);
// }

// function borderTopLeftRadius(v) {
//     @include dp2rem(borderTopLeftRadius, v);
// }

// function borderTopRightRadius(v) {
//     @include dp2rem(borderTopRightRadius, v);
// }

// function borderBottomRightRadius(v) {
//     @include dp2rem(borderBottomRightRadius, v);
// }

// function borderBottomLeftRadius(v) {
//     @include dp2rem(borderBottomLeftRadius, v);
// }

// function borderWidth(v: '0.5px') {
//     stripd: stripUnits(v);

//     @if (stripd == 0.5) {
//         borderWidth: v * 2;
//         .#{cssPrefix}hairlines & {
//             borderWidth: v;
//         }
//     } @else {
//         borderWidth: v;
//     }
// }

module.exports = {
    // dp2rem,
    // ellipsis,
    // multiLineEllipsis,
    // centerTl,
    // centerTd ,
    // size,
    // position,
    // triangle,
    // flexbox,
    // flex,
    // flexboxInline,
    // justifyContent,
    // flexDirection,
    // alignItems,
    // transform,
    // boxPack,
    // boxAlign,
    // overflowScroll,
    // fontSize,
    // width,
    // height,
    // lineHeight,
    // minWidth,
    // maxWidth,
    // minHeight,
    // maxHeight,
    // top,
    // right,
    // bottom,
    // left,
    // paddingTop,
    // paddingRight,
    // paddingBottom,
    // paddingLeft,
    padding: padding,
    margin: margin,
    border: border
};