"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
/**
 * @namespace ua for h5
 */
function UAparser() {
    //某些奇葩的Android手机拿userAgent会为空,或者有权限问题
    var userAgent = "";
    var unKnown = false;
    var appInfo = {};
    try {
        userAgent = window.navigator.userAgent.toLowerCase();
        if (!userAgent || userAgent == "") {
            unKnown = true;
        }
    } catch (e) {
        unKnown = true;
    }
    var OS = {
        ios: /iPhone|iPod|iPad|IOS/i.test(userAgent),
        iphone: /iPhone/i.test(userAgent),
        ipod: /iPod/i.test(userAgent),
        ipad: /iPad/i.test(userAgent),
        iphoneVersion: (userAgent.match(/.+(?:iphone\ os)[\/: ]([\d_]+)/) || [0, 0])[1].toString().split('_').join('.'),
        ipadVersion: (userAgent.match(/.+(?:cpu\ os)[\/: ]([\d_]+)/) || [0, 0])[1].toString().split('_').join('.'),

        android: /Android/i.test(userAgent),
        androidPhone: /(?=.*\bAndroid\b)(?=.*\bMobile\b)/i.test(userAgent),
        androidPad: /Android/i.test(userAgent) && !/(?=.*\bAndroid\b)(?=.*\bMobile\b)/i.test(userAgent),
        androidVersion: (userAgent.match(/.+(?:android)[\/: ]([\d.]+)/) || [0, 0])[1]
    };

    var ver = 0,
        osname = 'Unknown';
    if (OS.iphone) {
        osname = 'iphone';
        ver = OS.iphoneVersion;
    } else if (OS.ipod) {
        osname = 'ipod';
        ver = OS.iphoneVersion;
    } else if (OS.ipad) {
        osname = 'ipad';
        ver = OS.ipadVersion;
    } else if (OS.android) {
        osname = OS.androidPhone ? 'androidPhone' : 'androidPad';
        ver = OS.androidVersion;
    }

    appInfo.osVersion = ver;

    // appInfo.platform = osname;

    appInfo.iphone = userAgent.match(/iphone os/i) == "iphone os" || OS.iphone || OS.ipod;

    appInfo.ipad = userAgent.match(/ipad/i) == "ipad" || OS.ipad;

    appInfo.android = 'unKnown' || userAgent.match(/android/i) == "android" || OS.android || OS.androidPhone || OS.androidPad;

    appInfo.ios = appInfo.iphone || appInfo.ipad;

    appInfo.appName = /AliApp\(QN\//i.test(userAgent) ? 'QN' : 'unKnown';

    appInfo.platform = appInfo.ios ? 'iOS' : appInfo.android === true ? 'android' : 'unKnown';

    appInfo.isInAliApp = /AliApp/i.test(userAgent);

    appInfo.appVersion = appInfo.appName === 'QN' ? (userAgent.match(/AliApp\(QN\/(\d+(\.\d+){0,3})?\)/i) || [])[1] : 'unKnown';
    // alert( (userAgent.match(/AliApp\(QN\/(\d+(\.\d+){0,2})?\)/i) || [])[1]);
    return appInfo;
};
exports.default = UAparser;
module.exports = exports["default"];