/** @jsx createElement */

/**
 * Copyright (c) 2015-present, Alibaba Group Holding Limited.
 * All rights reserved.
 *
 * @providesModule
 */
'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.show = show;
exports.hide = hide;

var _rax = require('rax');

var _nukeEnv = require('../../../nuke-env/lib/index.js');

var _nukeEnv2 = _interopRequireDefault(_nukeEnv);

var _picker = require('./picker.js');

var _picker2 = _interopRequireDefault(_picker);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var isWeex = _nukeEnv2.default.isWeex;

var noop = function noop() {};

var pickerInstance = null,
    container = null;

function show() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var onSelect = arguments[1];
    var onCancel = arguments[2];
    var afterOpen = arguments[3];
    var onFail = arguments[4];

    onSelect = onSelect || noop;
    afterOpen = afterOpen || noop;
    onFail = onFail || noop;
    onCancel = onCancel || noop;

    var title = options.title,
        dataSource = options.dataSource,
        selectedKey = options.selectedKey,
        _options$maskClosable = options.maskClosable,
        maskClosable = _options$maskClosable === undefined ? true : _options$maskClosable,
        visible = options.visible,
        value = options.value,
        content = options.content,
        children = options.children,
        others = _objectWithoutProperties(options, ['title', 'dataSource', 'selectedKey', 'maskClosable', 'visible', 'value', 'content', 'children']);

    if (!dataSource) {
        onFail({ 'err': 'empty dataSource' });
        return;
    }
    if (!selectedKey) {
        if (dataSource[0].children) {
            selectedKey = [dataSource[0]['key'], dataSource[0].children[0]['key']];
        } else {
            selectedKey = dataSource[0]['key'];
        }
    }
    if (isWeex) {
        var QAPPicker = require('@weex-module/qappicker');
        QAPPicker.show({
            dataSource: dataSource,
            title: title,
            maskClosable: maskClosable,
            selectedKey: (typeof selectedKey === 'undefined' ? 'undefined' : _typeof(selectedKey)) === 'object' ? selectedKey : String(selectedKey),
            type: 'default'
        }, function (e) {
            afterOpen(e);
        }, function (e) {
            onFail(e);
        }, function (e) {
            if ((typeof e === 'undefined' ? 'undefined' : _typeof(e)) === 'object' && e.cancel === true) {
                onCancel(e);
                return;
            }
            if (!Array.isArray(e)) {

                e = [e];
            }
            onSelect(e);
        });
    } else {
        var afterCloseCallback = function afterCloseCallback() {
            (0, _rax.unmountComponentAtNode)(container);
            document.body.removeChild(container);

            pickerInstance = picker = container = null;
        };

        var onCancelCallback = function onCancelCallback() {
            onCancel({ cancel: true });
        };

        var afterOpenCallback = function afterOpenCallback(d) {
            afterOpen(d);
        };

        if (!selectedKey) {
            if (dataSource[0].children) {
                selectedKey = [dataSource[0]['key'], dataSource[0].children[0]['key']];
            } else {
                selectedKey = [dataSource[0]['key']];
            }
        }
        if (typeof selectedKey === 'string') {
            selectedKey = [selectedKey];
        }

        var picker = (0, _rax.createElement)(_picker2.default, _extends({}, others, { dataSource: dataSource, selectedKey: value || selectedKey, defaultVisible: true,
            afterOpen: afterOpenCallback, afterClose: afterCloseCallback, onDone: onSelect, onCancel: onCancelCallback }));

        if (!container) {
            container = document.createElement('div');
            container.setAttribute("id", '_nuke_wrap');
            container.setAttribute("ref", '_nuke_wrap');
            document.body.appendChild(container);
            container = document.getElementById('_nuke_wrap');
        }
        (0, _rax.render)(picker, (0, _rax.findDOMNode)(document.getElementById('_nuke_wrap')), function () {
            pickerInstance = this;
        });
    }
}

function hide() {
    if (isWeex) {
        // native 暂不支持
    } else {

        if (pickerInstance) {
            pickerInstance.hide();
        }
    }
}