/** @jsx createElement */

/**
 * Copyright (c) 2015-present, Alibaba Group Holding Limited.
 * All rights reserved.
 *
 * @providesModule
 */
'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.show = show;
exports.hide = hide;

var _rax = require('rax');

var _nukeEnv = require('../../../nuke-env/lib/index.js');

var _nukeEnv2 = _interopRequireDefault(_nukeEnv);

var _picker = require('./picker.js');

var _picker2 = _interopRequireDefault(_picker);

var _util = require('./util.js');

var _util2 = _interopRequireDefault(_util);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var isWeex = _nukeEnv2.default.isWeex,
    appInfo = _nukeEnv2.default.appInfo;


var noop = function noop() {};

var defaultOptions = {
    afterOpen: noop,
    afterClose: noop
};

var pickerInstance = null,
    container = null;

function show() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var onNotify = arguments[1];
    var onCancel = arguments[2];
    var afterOpen = arguments[3];
    var onFail = arguments[4];

    options = _extends({}, defaultOptions, options);
    onNotify = onNotify || noop;
    onCancel = onCancel || noop;
    afterOpen = afterOpen || noop;
    onFail = onFail || noop;

    var _options = options,
        title = _options.title,
        _options$range = _options.range,
        range = _options$range === undefined ? ['1970/1/1 00:00:00', '2099/12/31 23:59:59'] : _options$range,
        type = _options.type,
        _options$maskClosable = _options.maskClosable,
        maskClosable = _options$maskClosable === undefined ? false : _options$maskClosable,
        others = _objectWithoutProperties(_options, ['title', 'range', 'type', 'maskClosable']);

    function formatDefaultDate(date, type) {
        if (type === 'time') {
            return date;
        }
        var d = date ? new Date(date) : new Date();
        var str = '';
        if (d) {
            str = (0, _util2.default)(d, type, '-');
        }
        return str;
    }
    if (isWeex) {
        var QAPPicker = require('@weex-module/qapdatepicker');
        for (var i = 0; i < range.length; i++) {
            range[i] = (0, _util2.default)(new Date(range[i]), type, '-');
        }

        QAPPicker.show({
            range: range,
            title: title,
            maskClosable: maskClosable,
            default: formatDefaultDate(options.default || range[0], type),
            type: type
        }, function (e) {
            afterOpen(e);
        }, function (e) {
            onFail(e);
        }, function (e) {
            if ((typeof e === 'undefined' ? 'undefined' : _typeof(e)) === 'object' && e.cancel) {
                onCancel(e);
                return;
            }
            if (typeof e === 'string') {
                e = e.replace(/-/g, '/');
            }
            function getValueString(value) {
                if (parseInt(value, 10) < 10) {
                    return '0' + parseInt(value, 10).toString();
                } else {
                    return parseInt(value, 10).toString();
                }
            }
            if (type === 'time' && appInfo.platform === 'iOS') {
                // alert(e);
                var date = new Date(e);
                e = getValueString(date.getHours()) + ':' + getValueString(date.getMinutes()) + ':' + getValueString(date.getSeconds());
            }

            onNotify(e);
        });
    } else {
        var afterCloseCallback = function afterCloseCallback() {
            (0, _rax.unmountComponentAtNode)(container);
            document.body.removeChild(container);

            pickerInstance = picker = container = null;
            // afterClose();
        };

        var onCancelCallback = function onCancelCallback() {
            onCancel({ cancel: true });
        };

        var onDoneCallback = function onDoneCallback(dateArr) {
            var dateStr = '';
            if (type === 'date') {
                dateStr = dateArr[0] + '/' + dateArr[1] + '/' + dateArr[2];
            } else if (type === 'time') {
                var now = new Date();
                dateStr = now.getFullYear().toString() + '/' + (now.getMonth() + 1).toString() + '/' + now.getDate().toString() + ' ' + dateArr[0] + ':' + dateArr[1] + ':' + dateArr[2];
            } else {
                dateStr = dateArr[0] + '/' + dateArr[1] + '/' + dateArr[2] + ' ' + dateArr[3] + ':' + dateArr[4] + ':' + dateArr[5];
            }
            onNotify(dateStr);
        };

        var afterOpenCallback = function afterOpenCallback(d) {
            afterOpen(d);
        };

        var picker = (0, _rax.createElement)(_picker2.default, _extends({}, others, {
            type: type,
            range: range,
            title: title,
            'default': options.default,
            defaultVisible: true,
            afterOpen: afterOpenCallback,
            afterClose: afterCloseCallback,
            onDone: onDoneCallback,
            onCancel: onCancelCallback
        }));

        if (!container) {
            container = document.createElement('div');
            container.setAttribute('id', '_nuke_wrap');
            document.body.appendChild(container);
            container = document.getElementById('_nuke_wrap');
        }

        (0, _rax.render)(picker, (0, _rax.findDOMNode)(document.getElementById('_nuke_wrap')), function () {
            pickerInstance = this;
        });
    }
}

function hide() {
    if (isWeex) {
        // native 暂不支持
    } else {
        if (pickerInstance) {
            pickerInstance.hide();
        }
    }
}