'use strict';

var _uri = require('./mods/uri.js');

var _uri2 = _interopRequireDefault(_uri);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var urlHelper = {

  urlParse: function urlParse(url) {
    if (!url || typeof url !== 'string') return {};
    // add qap:// & qap:/// support
    var reg = /(qap:\/{2,3})/g;
    url = url.replace(reg, "qap:///");

    var obj = {};
    var uri = new _uri2.default(url);

    obj.protocol = uri.protocol() + ':';
    obj.hostname = uri.host();
    obj.port = uri.port();
    obj.host = obj.hostname + (obj.port ? ':' + obj.port : '');
    obj.origin = obj.protocol + '//' + obj.host;
    obj.pathname = uri.path();
    obj.search = uri.query();
    obj.hash = uri.anchor() ? '#' + uri.anchor() : '';
    return obj;
  },
  realPath: function realPath(path) {

    var DOT_RE = /\/\.\//g;
    var DOUBLE_DOT_RE = /\/[^/]+\/\.\.\//;
    var MULTI_SLASH_RE = /([^:/])\/+\//g;

    path = path.replace(DOT_RE, "/");

    path = path.replace(MULTI_SLASH_RE, "$1/");

    // a/b/c/../../d  ==>  a/b/../d  ==>  a/d
    while (path.match(DOUBLE_DOT_RE)) {
      path = path.replace(DOUBLE_DOT_RE, "/");
    }

    return path;
  },
  getSearchParameter: function getSearchParameter(search, paramName) {
    var searchString = search.substring(1),
        i,
        val,
        params = searchString.split("&");

    for (i = 0; i < params.length; i++) {
      val = params[i].split("=");
      if (val[0] === paramName) {
        return val[1];
      }
    }
    return null;
  }
};
module.exports = urlHelper;