/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 * 
 */
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _core = require('../core');

var _core2 = _interopRequireDefault(_core);

var _rax = require('rax');

var _nukeView = require('nuke-view');

var _nukeView2 = _interopRequireDefault(_nukeView);

var _nukeText = require('nuke-text');

var _nukeText2 = _interopRequireDefault(_nukeText);

var _nukeImage = require('nuke-image');

var _nukeImage2 = _interopRequireDefault(_nukeImage);

var _mapStyle = require('./mapStyle');

var _mapStyle2 = _interopRequireDefault(_mapStyle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ApplyAnimatedValues(instance, props) {

  (0, _rax.setNativeProps)(instance, {
    style: (0, _mapStyle2.default)(props.style)
  });
}

var injectApplyAnimatedValues = _core2.default.inject.ApplyAnimatedValues;
injectApplyAnimatedValues(ApplyAnimatedValues);

var RequestAnimationFrame;
var CancelAnimationFrame;

if (typeof requestAnimationFrame !== 'undefined') {
  RequestAnimationFrame = function RequestAnimationFrame(cb) {
    return requestAnimationFrame(cb);
  };
  CancelAnimationFrame = function CancelAnimationFrame(id) {
    return cancelAnimationFrame(id);
  };
  // Works around a rare bug in Safari 6 where the first request is never invoked.
  requestAnimationFrame(function () {});
} else {
  var lastTime = 0;
  RequestAnimationFrame = function RequestAnimationFrame(callback) {
    var currTime = Date.now();
    var timeDelay = Math.max(0, 16 - (currTime - lastTime));
    lastTime = currTime + timeDelay;
    return setTimeout(function () {
      callback(Date.now());
    }, timeDelay);
  };

  CancelAnimationFrame = function CancelAnimationFrame(id) {
    clearTimeout(id);
  };
}

var injectRequestAnimationFrame = _core2.default.inject.RequestAnimationFrame;
injectRequestAnimationFrame(RequestAnimationFrame);

var injectCancelAnimationFrame = _core2.default.inject.CancelAnimationFrame;
injectCancelAnimationFrame(CancelAnimationFrame);

exports.default = _extends({}, _core2.default, {
  View: _core2.default.createAnimatedComponent(_nukeView2.default),
  Text: _core2.default.createAnimatedComponent(_nukeText2.default),
  Image: _core2.default.createAnimatedComponent(_nukeImage2.default)
});
module.exports = exports['default'];