'use strict';

import { varLoader } from 'nuke-var-loader';

////
/// @group Variables 变量
/// @module corner: 边角
/// @category style
////







let cornerRadiusBase = varLoader('corner-radius-base', '8');

/// Radius 0
/// @export
/// @type String
let cornerRadiusR0 = varLoader('corner-radius-r0', '0');

/// Radius 1
/// @export
/// @type String
let cornerRadiusR1 = varLoader('corner-radius-r1', '8');

/// Radius 2
/// @export
/// @type String
let cornerRadiusR2 = varLoader('corner-radius-r2', '4');

/// Radius Half
/// @export
let cornerRadiusHalf = varLoader('corner-radius-half', '50%');

/// Radius Circle
/// @export
let cornerRadiusCircle = varLoader('corner-radius-circle', '100%');

let cornerSidesBase = varLoader('corner-sides-base', "base");
let cornerSidesTop = varLoader('corner-sides-top', "top");
let cornerSidesRight = varLoader('corner-sides-right', "right");
let cornerSidesBottom = varLoader('corner-sides-bottom', "bottom");
let cornerSidesLeft = varLoader('corner-sides-left', "left");
let cornerSidesTl = varLoader('corner-sides-tl', "topLeft");
let cornerSidesTr = varLoader('corner-sides-tr', "topRight");
let cornerSidesBl = varLoader('corner-sides-bl', "bottomLeft");
let cornerSidesBr = varLoader('corner-sides-br', "bottomRight");

/// Corner R0
/// @access private
/// @unconfigurable
let cornerR0 = varLoader('corner-r0', cornerMaker(cornerRadiusBase, cornerRadiusR0));

/// Corner R0 (top)
/// @access private
/// @unconfigurable
let cornerR0Top = varLoader('corner-r0-top', cornerMaker(cornerSidesTop, cornerRadiusR0));

/// Corner R0 (right)
/// @access private
/// @unconfigurable
let cornerR0Right = varLoader('corner-r0-right', cornerMaker(cornerSidesRight, cornerRadiusR0));

/// Corner R0 (bottom)
/// @access private
/// @unconfigurable
let cornerR0Bottom = varLoader('corner-r0-bottom', cornerMaker(cornerSidesBottom, cornerRadiusR0));

/// Corner R0 (left)
/// @access private
/// @unconfigurable
let cornerR0Left = varLoader('corner-r0-left', cornerMaker(cornerSidesLeft, cornerRadiusR0));

/// Corner R1
/// @unconfigurable
/// @access private
let cornerR1 = varLoader('corner-r1', cornerMaker());

/// Corner R1 (top)
/// @access private
/// @unconfigurable
let cornerR1Top = varLoader('corner-r1-top', cornerMaker(cornerSidesTop));

/// Corner R1 (right)
/// @access private
/// @unconfigurable
let cornerR1Right = varLoader('corner-r1-right', cornerMaker(cornerSidesRight));

/// Corner R1 (bottom)
/// @access private
/// @unconfigurable
let cornerR1Bottom = varLoader('corner-r1-bottom', cornerMaker(cornerSidesBottom));

/// Corner R1 (left)
/// @access private
/// @unconfigurable
let cornerR1Left = varLoader('corner-r1-left', cornerMaker(cornerSidesLeft));

/// Corner R2
/// @access private
/// @unconfigurable
let cornerR2 = varLoader('corner-r2', cornerMaker(cornerRadiusBase, cornerRadiusR2));

/// Corner R2 (top)
/// @access private
/// @unconfigurable
let cornerR2Top = varLoader('corner-r2-top', cornerMaker(cornerSidesTop, cornerRadiusR2));

/// Corner R2 (right)
/// @access private
/// @unconfigurable
let cornerR2Right = varLoader('corner-r2-right', cornerMaker(cornerSidesRight, cornerRadiusR2));

/// Corner R2 (bottom)
/// @access private
/// @unconfigurable
let cornerR2Bottom = varLoader('corner-r2-bottom', cornerMaker(cornerSidesBottom, cornerRadiusR2));

/// Corner R2 (left)
/// @access private
/// @unconfigurable
let cornerR2Left = varLoader('corner-r2-left', cornerMaker(cornerSidesLeft, cornerRadiusR2));


/// Corner Half
/// @access private
/// @unconfigurable
let cornerRHalf = varLoader('corner-r-half', cornerMaker(cornerRadiusBase, cornerRadiusHalf));

/// Corner Half (top)
/// @access private
/// @unconfigurable
let cornerRHalfTop = varLoader('corner-r-half-top', cornerMaker(cornerSidesTop, cornerRadiusHalf));

/// Corner Half (right)
/// @access private
/// @unconfigurable
let cornerRHalfRight = varLoader('corner-r-half-right', cornerMaker(cornerSidesRight, cornerRadiusHalf));

/// Corner Half (bottom)
/// @access private
/// @unconfigurable
let cornerRHalfBottom = varLoader('corner-r-half-bottom', cornerMaker(cornerSidesBottom, cornerRadiusHalf));

/// Corner Half (left)
/// @access private
/// @unconfigurable
let cornerRHalfLeft = varLoader('corner-r-half-left', cornerMaker(cornerSidesLeft, cornerRadiusHalf));

/// Corner Circle
/// @access private
/// @unconfigurable
let cornerRCircle = varLoader('corner-r-circle', cornerMaker(cornerRadiusBase, cornerRadiusCircle));

/// Corner Circle (top)
/// @access private
/// @unconfigurable
let cornerRCircleTop = varLoader('corner-r-circle-top', cornerMaker(cornerSidesTop, cornerRadiusCircle));

/// Corner Circle (right)
/// @access private
/// @unconfigurable
let cornerRCircleRight = varLoader('corner-r-circle-right', cornerMaker(cornerSidesRight, cornerRadiusCircle));

/// Corner Circle (bottom)
/// @access private
/// @unconfigurable
let cornerRCircleBottom = varLoader('corner-r-circle-bottom', cornerMaker(cornerSidesBottom, cornerRadiusCircle));

/// Corner Circle (left)
/// @access private
/// @unconfigurable
let cornerRCircleLeft = varLoader('corner-r-circle-left', cornerMaker(cornerSidesLeft, cornerRadiusCircle));




/// 圆角生成器
///
/// @access private
///
/// @param {String} $side [$corner-sides-base] - 需要加圆角的面
/// @param {String} $radius [$corner-radius-base] - 圆角曲率
///
/// @example.rxscss -.rxscss 用法
///   .element {
///     border-radius: corner-maker();
///   }
///
/// @example css - CSS 输出
///   .element {
///     border-radius: 3px 3px 3px 3px;
///   }
///
/// @return {List}

function cornerMaker(side=cornerSidesBase, radius=cornerRadiusBase) {

    let tl = radius;
    let tr = radius;
    let bl = radius;
    let br = radius;

    if (side ==  'top') {
        br = 0;
        bl = 0;
    } else if (side == 'right') {
        tl = 0;
        bl = 0;
    } else if (side == 'down') {
        tr = 0;
        tl = 0;
    } else if (side == 'left') {
        tr = 0;
        br = 0;
    }

    return `${tl} ${tr} ${br} ${bl}`;
}


module.exports = {
    ['corner-radius-base']: cornerRadiusBase,
    ['corner-radius-r0']: cornerRadiusR0,
    ['corner-radius-r1']: cornerRadiusR1,
    ['corner-radius-r2']: cornerRadiusR2,
    ['corner-radius-half']: cornerRadiusHalf,
    ['corner-radius-circle']: cornerRadiusCircle,
    ['corner-sides-base']: cornerSidesBase,
    ['corner-sides-top']: cornerSidesTop,
    ['corner-sides-right']: cornerSidesRight,
    ['corner-sides-bottom']: cornerSidesBottom,
    ['corner-sides-left']: cornerSidesLeft,
    ['corner-sides-tl']: cornerSidesTl,
    ['corner-sides-tr']: cornerSidesTr,
    ['corner-sides-bl']: cornerSidesBl,
    ['corner-sides-br']: cornerSidesBr,
    ['corner-r0']: cornerR0,
    ['corner-r0-top']: cornerR0Top,
    ['corner-r0-right']: cornerR0Right,
    ['corner-r0-bottom']: cornerR0Bottom,
    ['corner-r0-left']: cornerR0Left,
    ['corner-r1']: cornerR1,
    ['corner-r1-top']: cornerR1Top,
    ['corner-r1-right']: cornerR1Right,
    ['corner-r1-bottom']: cornerR1Bottom,
    ['corner-r1-left']: cornerR1Left,
    ['corner-r2']: cornerR2,
    ['corner-r2-top']: cornerR2Top,
    ['corner-r2-right']: cornerR2Right,
    ['corner-r2-bottom']: cornerR2Bottom,
    ['corner-r2-left']: cornerR2Left,
    ['corner-r-half']: cornerRHalf,
    ['corner-r-half-top']: cornerRHalfTop,
    ['corner-r-half-right']: cornerRHalfRight,
    ['corner-r-half-bottom']: cornerRHalfBottom,
    ['corner-r-half-left']: cornerRHalfLeft,
    ['corner-r-circle']: cornerRCircle,
    ['corner-r-circle-top']: cornerRCircleTop,
    ['corner-r-circle-right']: cornerRCircleRight,
    ['corner-r-circle-bottom']: cornerRCircleBottom,
    ['corner-r-circle-left']: cornerRCircleLeft,
    cornerMaker
}
