/** @jsx createElement */

/**
 * Copyright (c) 2015-present, Alibaba Group Holding Limited.
 * All rights reserved.
 *
 * @providesModule
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _rax = require('rax');

var _nukeUtil = require('nuke-util');

var _nukeEnv = require('nuke-env');

var Navigator = {
  setTitle: function setTitle(title) {
    if (_nukeEnv.isWeex) {
      var navigator = require('@weex-module/navigator');
      try {
        navigator.setTitle({ title: title }, function () {});
      } catch (e) {
        document.title = title;
      }
    }
  },
  convertURL: function convertURL(url) {
    if (url.indexOf('qap://') > -1) {
      var options = {
        refer: window.location.href
      };
      if (typeof window.__QAP__ !== 'undefined' && __QAP__.package && __QAP__.package.config && __QAP__.package.config.WebRootPath) {
        options.webRootPath = __QAP__.package.config.WebRootPath;
      }
      url = (0, _nukeUtil.urlHandler)(url, options);
    }
    return url;
  },
  serialize: function serialize(obj) {
    var str = '';
    for (var p in obj) {
      str = '&' + p + '=' + encodeURIComponent(obj[p]);
    }
    return str.substring(1);
  },
  push: function push(url, title) {
    var animated = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
    var param = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

    if (_nukeEnv.isWeex) {
      var navigator = require('@weex-module/navigator');
      try {
        navigator.push({
          url: url,
          title: title
        }, function (e) {});
      } catch (e) {}
    } else {
      url = this.convertURL(url);
      if (url) {
        if (_nukeUtil.urlHelper.urlParse(url).search.length > 0) {
          url = url + '&' + this.serialize(param);
        } else {
          url = url + '?' + this.serialize(param);
        }
        window.location.href = url;
      }
    }
  }
};
exports.default = Navigator;
module.exports = exports['default'];