/** @jsx createElement */

'use strict';

import { createElement, Component, PropTypes, findDOMNode } from 'rax';
import View from 'nuke-view';
import { isWeex, isWeb, appInfo } from 'nuke-env';
import SwipeEvent from 'nuke-swipe';
import * as defaultStyle from '../styles.js';
import {
    HANDLER_SIZE,
    INVALID_COLOR,
    DISABLE_COLOR,
    VALIDE_COLOR,
    BAR_HEIGHT
} from '../default.variable';

let expressionBinding = {};
try {
    expressionBinding = require('@weex-module/expressionBinding');
} catch (e) {}

class Range extends Component {
    constructor(props) {
        super(props);

        this.weexStartHandler1 = this.weexStartHandler1.bind(this);
        this.weexStartHandler2 = this.weexStartHandler2.bind(this);
        this.weexEndHandler = this.weexEndHandler.bind(this);
        this.bindExp = this.bindExp.bind(this);
        this.enableBinding = this.enableBinding.bind(this);
        this.webStart = this.webStart.bind(this);
        this.webMove = this.webMove.bind(this);
        this.webMove2 = this.webMove2.bind(this);
        this.renderHandler = this.renderHandler.bind(this);
        this.state = {
            start: 0,
            end: 0,
            active: false,
            value: props.value || props.defaultValue || 0,
            barWidth: 0,
            timeout: 100,
            left: 0,
            selectRange: [0, 0],
            minDiffX: 0
        };
        this.selectRange = [0, 0];
        if (isWeex && this.props.highPerformance) {
            this.dpr = 1;
            this.ep = true;
        } else {
            this.dpr = 2;
            this.ep = false;
        }
    }

    componentDidMount() {
        this.block1 = findDOMNode(this.refs['slide-block-1']); // 左侧滑块
        this.block2 = findDOMNode(this.refs['slide-block-2']); // 右侧滑块
        this.valueBar = findDOMNode(this.refs['slide-value-bar']); // 黄色值条
        this.barContainer = findDOMNode(this.refs['slide-bar-container']); // 滚动条容器

        this.initBaseEnv(); // ep设置，滑块位置
    }
    // 根据value和length计算x方向偏移值
    getDistanceByValue(value) {
        return (
            (value - this.props.min) /
            (this.props.max - this.props.min) *
            this.length
        );
    }

    getValueByDistance(diffX) {
        return Math.round(
            diffX / this.length * (this.props.max - this.props.min) +
                this.props.min
        );
    }

    initBaseEnv = () => {
        const { slider, highPerformance, min, max, style } = this.props;
        this.length = style.width || defaultStyle.container.width; // 可滑动的距离，未计算padding
        this.leftDiffX = 0;
        const newData = { selectRange: this.state.selectRange };
        if (!slider || slider === 'single') {
            newData.start = this.getDistanceByValue(this.state.value);
        } else if (slider === 'double') {
            newData.start = this.getDistanceByValue(this.state.value[0]);
            newData.end = this.getDistanceByValue(this.state.value[1]);
            newData.barWidth = newData.end - newData.start;
            this.selectRange = this.state.value || this.state.defaultValue;
            newData.minDiffX = this.state.minDiffX / (max - min) * this.length;
        } else {
            throw new Error(
                'unsupport slider type,use single or double replace'
            );
        }
        if (appInfo.platform === 'android') {
            newData.timeout = 250;
        }
        this.setState({
            ...newData
        });

        if (this.ep && appInfo.platform !== 'android') {
            this.enableBinding();
            this.bindExp();
        }
        // android渲染性能不佳，动画绑定延时进行。
        if (this.ep && appInfo.platform === 'android') {
            setTimeout(() => {
                this.enableBinding();
                this.bindExp();
            }, 100);
        }
    };

    enableBinding() {
        expressionBinding.enableBinding(this.block1.ref, 'pan');
        this.block2 && expressionBinding.enableBinding(this.block2.ref, 'pan');
        expressionBinding.enableBinding(this.valueBar.ref, 'pan');
        setTimeout(() => {
            const dom = require('@weex-module/dom');
            dom.getComponentRect(this.barContainer, option => {
                if (!option || !option.size) return;
                const { left } = option.size;
                this.leftDiffX = left;
            });
        }, 100);
    }
    componentWillReceiveProps(nextProps) {
        if (nextProps.value != this.props.value && !this.paning) {
            this.setState(
                {
                    value: nextProps.value
                },
                () => {
                    this.initBaseEnv();
                }
            );
        }
    }

    computeContainerStyle() {
        const { handlerStyle, style } = this.props;
        const handlerWidth = handlerStyle.width
            ? handlerStyle.width
            : HANDLER_SIZE;
        const handlerHeight = handlerStyle.height
            ? handlerStyle.height
            : HANDLER_SIZE;
        return {
            ...style,
            width: this.length + handlerWidth,
            height: handlerHeight
        };
    }

    computRangeBarStyle() {
        const { afterBarStyle } = this.props;
        const barHeight = afterBarStyle.height
            ? afterBarStyle.height
            : BAR_HEIGHT;
        const invalidColor = afterBarStyle.color
            ? afterBarStyle.color
            : INVALID_COLOR;
        return {
            width: this.length,
            height: barHeight,
            backgroundColor: invalidColor,
            flexDirection: 'row',
            overflow: 'hidden'
        };
    }

    computValueBarStyle() {
        let left = 0;
        let width = 0;
        const { slider, disabled, barStyle } = this.props;
        if (!slider || slider === 'single') {
            width = this.state.start;
        } else {
            left = this.state.start;
            width = this.state.end - this.state.start;
        }
        const barHeight = barStyle.height ? barStyle.height : BAR_HEIGHT;
        const validColor = barStyle.color ? barStyle.color : VALIDE_COLOR;
        return {
            width,
            height: barHeight,
            transform: `translateX(${left / this.dpr}px)`,
            backgroundColor: disabled ? DISABLE_COLOR : validColor
        };
    }

    computBlock1Style() {
        return { transform: `translateX(${this.state.start / this.dpr}px)` };
    }

    computBlock2Style() {
        return { transform: `translateX(${this.state.end / this.dpr}px)` };
    }

    renderHandler() {
        const { handlerStyle, style, slider } = this.props;
        // native handle
        const blockEle1 = (
            <View
                ref="slide-block-1"
                onTouchStart={this.weexStartHandler1}
                onTouchEnd={this.weexEndHandler}
                style={[
                    defaultStyle.slideBlock,
                    handlerStyle,
                    this.computBlock1Style()
                ]}
                preventMoveEvent
            >
                <View />
            </View>
        );
        const blockEle2 = (
            <View
                ref="slide-block-2"
                t="siwp2"
                onTouchStart={this.weexStartHandler2}
                onTouchEnd={this.weexEndHandler}
                style={[
                    defaultStyle.slideBlock,
                    handlerStyle,
                    this.computBlock2Style()
                ]}
                preventMoveEvent
            >
                <View />
            </View>
        );
        // h5 handle
        const webBlockEle1Style = Object.assign(
            {},
            defaultStyle.slideBlock,
            handlerStyle,
            { positon: 'absolute' },
            this.computBlock1Style()
        );

        const webBlockEle1 = (
            <SwipeEvent
                ref="slide-block-1"
                onSwipeBegin={this.webStart}
                onSwipe={this.webMove}
                onEnd={this.webEnd}
                horizontalThreshold={10}
                initialVelocityThreshold={0.01}
                vertical={false}
                handlerStyle={webBlockEle1Style}
            />
        );
        const webBlockEle2Style = Object.assign(
            {},
            defaultStyle.slideBlock,
            handlerStyle,
            { positon: 'absolute' },
            this.computBlock2Style()
        );
        const webBlockEle2 = (
            <SwipeEvent
                ref="slide-block-2"
                onSwipeBegin={this.webStart}
                onSwipe={this.webMove2}
                onSwipeEnd={this.webEnd}
                horizontalThreshold={10}
                initialVelocityThreshold={0.01}
                handlerStyle={webBlockEle2Style}
            />
        );
        if (this.ep) {
            if (slider !== 'double') {
                return blockEle1;
            }
            return [blockEle1, blockEle2];
        }
        if (slider !== 'double') {
            return webBlockEle1;
        }
        return [webBlockEle1, webBlockEle2];
    }

    render() {
        const { style, disabled, slider, handlerStyle, ...others } = this.props;

        return (
            <View
                ref="slide-bar-container"
                style={[defaultStyle.container, this.computeContainerStyle()]}
            >
                <View style={[defaultStyle.range, this.computRangeBarStyle()]}>
                    <View
                        ref="slide-value-bar"
                        style={[
                            defaultStyle.value_bar,
                            this.computValueBarStyle()
                        ]}
                    >
                        <View ref="slide-value-bar-2" />
                    </View>
                </View>
                {this.renderHandler()}
            </View>
        );
    }

    weexStartHandler1() {
        if (isWeb) return;
        const { slider } = this.props;
        const dom = require('@weex-module/dom');
        this.paning = true;
        this.firstInterval = setInterval(() => {
            if (slider !== 'double') {
                dom.getComponentRect(this.valueBar, option => {
                    if (!option || !option.size) return;
                    const { width } = option.size;
                    const value = this.getValueByDistance(width);
                    this.props.onProcess && this.props.onProcess(value);
                });
            } else {
                dom.getComponentRect(this.block1, option => {
                    if (!option || !option.size) return;
                    const { left } = option.size;
                    this.selectRange[0] = this.getValueByDistance(
                        left - this.leftDiffX
                    );
                    this.props.onProcess &&
                        this.props.onProcess(this.selectRange);
                });
            }
        }, this.state.timeout);
    }

    weexStartHandler2() {
        if (isWeb) return;
        const dom = require('@weex-module/dom');
        this.paning = true;
        this.secondInterval = setInterval(() => {
            dom.getComponentRect(this.block2, option => {
                if (!option || !option.size) return;
                const { left } = option.size;
                this.selectRange[1] = this.getValueByDistance(
                    left - this.leftDiffX
                );
                this.props.onProcess && this.props.onProcess(this.selectRange);
            });
        }, this.state.timeout);
    }

    weexEndHandler() {
        if (isWeb) return;
        this.paning = false;
        this.firstInterval && clearInterval(this.firstInterval);
        this.secondInterval && clearInterval(this.secondInterval);
        const { slider } = this.props;
        const dom = require('@weex-module/dom');

        if (slider !== 'double') {
            setTimeout(() => {
                dom.getComponentRect(this.valueBar, option => {
                    if (option && option.size && option.size.width) {
                        const value = this.getValueByDistance(
                            option.size.width
                        );
                        this.props.onChange && this.props.onChange(value);
                    }
                });
            }, 50);
        } else {
            setTimeout(() => {
                dom.getComponentRect(this.block1, option => {
                    if (!option || !option.size) return;
                    const { left } = option.size;
                    this.selectRange[0] = this.getValueByDistance(
                        left - this.leftDiffX
                    );
                    this.props.onChange &&
                        this.props.onChange(this.selectRange);
                });
            }, 50);
        }
    }

    webStart(e) {
        this.webDiffX = e.distance;
    }
    webMove(e) {
        const distance = e.distance - this.webDiffX;
        this.webDiffX = e.distance;
        const start = this.state.start + distance * this.dpr;
        if (this.props.slider !== 'double') {
            if (start > this.length || start < 0) return;
        } else if (start > this.state.end - this.state.minDiffX || start < 0) {
            return;
        }
        this.setState({
            start
        });
        this.props.onProcess &&
            this.props.onProcess(this.getValueByDistance(start));
    }
    webMove2(e) {
        const distance = e.distance - this.webDiffX;
        this.webDiffX = e.distance;
        const end = this.state.end + distance * this.dpr;
        if (this.props.slider !== 'double') {
            if (end > this.length || end < 0) return;
        } else if (end > this.length || end < this.state.start) {
            return;
        }
        this.setState({
            end
        });
        this.props.onProcess &&
            this.props.onProcess([
                this.getValueByDistance(this.state.start),
                this.getValueByDistance(end)
            ]);
    }
    webEnd() {}
    bindExp() {
        const self = this;
        const { slider } = this.props;
        if (this.props.disabled || isWeb) {
            return;
        }
        let blockMax1 = 0;
        if (slider === 'double') {
            blockMax1 = this.state.end - this.state.minDiffX;
        } else {
            blockMax1 = this.length;
        }
        const blockMax2 = this.length;
        const blockMin2 = this.state.start + this.state.minDiffX;
        const barMax1 = this.state.end;
        const barMax2 = this.length - this.state.start;
        // 滑块1表达式
        const expBlock1 = `{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"min\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":${blockMax1}},{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"max\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"+\",\"children\":[{\"type\":\"Identifier\",\"value\":\"x\"},{\"type\":\"NumericLiteral\",\"value\":${
            self.state.start
        }}]},{\"type\":\"NumericLiteral\",\"value\":0}]}]}]}]}`;
        // 滑块2表达式
        const expBlock2 = `{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"min\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":${blockMax2}},{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"max\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"+\",\"children\":[{\"type\":\"Identifier\",\"value\":\"x\"},{\"type\":\"NumericLiteral\",\"value\":${
            self.state.end
        }}]},{\"type\":\"NumericLiteral\",\"value\":${blockMin2}}]}]}]}]}`;
        // valuebar表达式
        const expBar1 = `{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"min\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":${barMax1}},{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"max\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":0},{\"type\":\"-\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":${
            self.state.barWidth
        }},{\"type\":\"Identifier\",\"value\":\"x\"}]}]}]}]}]}`;
        // valuebar 范围表达式
        const expBar2 = `{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"min\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":${barMax2}},{\"type\":\"CallExpression\",\"children\":[{\"type\":\"Identifier\",\"value\":\"max\"},{\"type\":\"Arguments\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":0},{\"type\":\"+\",\"children\":[{\"type\":\"NumericLiteral\",\"value\":${
            self.state.barWidth
        }},{\"type\":\"Identifier\",\"value\":\"x\"}]}]}]}]}]}`;

        if (slider !== 'double') {
            const args = [
                {
                    element: this.block1.ref,
                    property: 'transform.translateX',
                    expression: expBlock1
                },
                {
                    element: this.valueBar.ref,
                    property: 'width',
                    expression: expBlock1
                }
            ];
            expressionBinding &&
                expressionBinding.createBinding(
                    this.block1.ref,
                    'pan',
                    '',
                    args,
                    e => {
                        if (e.state === 'end') {
                            this.paning = false;
                            const range = self.getRange();
                            // 限制diffX1范围
                            this.setState({
                                start: self.restrictValue(
                                    range.rangeX1,
                                    this.state.start + e.deltaX
                                )
                            });
                            self.bindExp();
                        }
                    }
                );
        } else {
            const args = [
                {
                    element: this.block1.ref,
                    property: 'transform.translateX',
                    expression: expBlock1
                },
                {
                    element: this.valueBar.ref,
                    property: 'transform.translateX',
                    expression: expBlock1
                },
                {
                    element: this.valueBar.ref,
                    property: 'width',
                    expression: expBar1
                }
            ];
            const args2 = [
                {
                    element: this.block2.ref,
                    property: 'transform.translateX',
                    expression: expBlock2
                },
                {
                    element: this.valueBar.ref,
                    property: 'width',
                    expression: expBar2
                }
            ];
            expressionBinding &&
                expressionBinding.createBinding(
                    this.block1.ref,
                    'pan',
                    '',
                    args,
                    e => {
                        if (e.state === 'end') {
                            this.paning = false;
                            const range = self.getRange();
                            // 限制diffX1范围
                            this.setState({
                                start: this.restrictValue(
                                    range.rangeX1,
                                    this.state.start + e.deltaX
                                ),
                                barWidth: this.restrictValue(
                                    range.rangeX1,
                                    this.state.barWidth - e.deltaX
                                )
                            });
                            self.bindExp();
                        }
                    }
                );
            expressionBinding &&
                expressionBinding.createBinding(
                    this.block2.ref,
                    'pan',
                    '',
                    args2,
                    e => {
                        if (e.state === 'end') {
                            this.paning = false;
                            const range = self.getRange();
                            this.setState({
                                end: self.restrictValue(
                                    range.rangeX2,
                                    this.state.end + e.deltaX
                                ),
                                barWidth: this.restrictValue(
                                    [0, this.length - this.state.start],
                                    this.state.barWidth + e.deltaX
                                )
                            });
                            // 限制diffX1范围
                            self.bindExp();
                        }
                    }
                );
        }
    }
    // 获取diffx1 diffx2 取值范围
    getRange = () => {
        if (this.props.slider !== 'double') {
            return {
                rangeX1: [0, this.length]
            };
        }
        return {
            rangeX1: [0, this.state.end - this.state.minDiffX],
            rangeX2: [this.state.start + this.state.minDiffX, this.length]
        };
    };
    // 限制取值范围
    restrictValue = (range, value) => {
        if (range && range.length && range.length === 2) {
            if (value < range[0]) {
                return range[0];
            } else if (value > range[1]) {
                return range[1];
            }
            return value;
        }
        return;
    };
}
Range.PropTypes = {
    slider: PropTypes.string,
    defaultValue: PropTypes.any,
    value: PropTypes.any,
    min: PropTypes.number,
    max: PropTypes.number,
    disabled: PropTypes.bool,
    highPerformance: PropTypes.bool,
    onChange: PropTypes.func,
    onProcess: PropTypes.func,
    style: PropTypes.obj,
    handlerStyle: PropTypes.obj,
    barStyle: PropTypes.obj,
    afterBarStyle: PropTypes.obj
};
Range.defaultProps = {
    slider: 'single',
    defaultValue: 0,
    min: 0,
    max: 100,
    disabled: false,
    highPerformance: true,
    handlerStyle: {},
    barStyle: {},
    afterBarStyle: {}
};
export default Range;
