"use strict";
/** @jsx createElement */
import {createElement, Component,PropTypes} from 'rax';
import { View, Text,TouchableHighlight,ScrollView,TouchableOpacity} from 'nuke-components';
import ListView from 'nuke-list-view';
import Slider from 'nuke-slider';
import Icon from 'nuke-icon';
import Badge from 'nuke-badge';
import Dimensions from 'nuke-dimensions';
import Pane from './pane.js';
import styles from './styles.js';
import Util from './util.js';

const WIDTH = 750;
const WINDOW_HEIGHT = Dimensions.get('window').height;

class TabSlider extends Component {
  constructor(props) {
    super(props);
    this.state = {
        active: props.active || 0
    }
  }

  slideTo = (index) => {
      this.refs.Slider.slideTo(index);
  }

  sliderChange(obj){
      console.log('切换完成',obj.index);
      this.setState({
          active:obj.index
      })
      this.props.onChange(obj.index);
  }
  /**
   * [onPress 选中第几个tab,自动tab时可用]
   * @method onPress
   * @param  {[number]} index [tab索引]
   */
  onPress(index){
      if(this.state.active !== index){
          this.refs.Slider.slideTo(index);
      }
  }
  /**
   * [_renderBar 根据pane数量，render对应导航]
   * @method _renderBar
   * @param  {[object]}   state    [description]
   * @param  {[object]}   props    [description]
   * 逻辑：
   * 当不是自定义bar时= 均分显示
   * 当是自定义bar时=》不再设置导航宽度，只居中显示，选中效果由用户自己实现
   */
  _renderBar(state,props){
    const children = this.getFormatChildren(props.children);
    if(!props.customBar){
            styles.navWrapStyle.width = 750/children.length;
    }

    var barArray = [],that = this;

    children.forEach((child,index)=>{
      let iconSrc = child.icon && child.icon.src;
      let fontStyle = styles.navItemTitle;

      if(index == state.active){
        fontStyle = Object.assign({},styles.selectFontStyle);
        if(child.icon && child.icon.selected){
          iconSrc = child.icon.selected;
        }
      }
      if(!props.customBar)
        barArray.push(
          <View style={styles.navWrapStyle}>
            <TouchableOpacity  onPress={that.onPress.bind(that,index)}>
                  <View>
                      {iconSrc ? <Icon size={'medium'} src={iconSrc} style={[styles.navItemIcon || {}]} /> : null}
                      <Text style={fontStyle}>{child.title}</Text>{child.num && child.num>0 ? <Badge count={child.num} style={[fontStyle,styles.navItemNum]}></Badge> : null}
                  </View>
            </TouchableOpacity>
          </View>
          )
      else {
        barArray.push(
          <View style={[styles.navWrapStyle],{alignItems:'center',justifyContent:'center'}}>
                  {child.renderTitleCustom()}
          </View>
        )
      }
    })
    return barArray;
  }
  _renderPane(children){
    var paneArray = [];
      children.forEach((child)=>{
        paneArray.push(<Pane style={child.style}>{child.children}</Pane>)
      })
    return paneArray;
  }

  /**
   * [getFormatChildren 获取children，format 导航信息]
   * @method getFormatChildren
   * @param  {[type]}          children [description]
   */

  getFormatChildren(children){
        var barArray = [];
        if(!children.length)
            barArray = [children.props];
        else
            children.forEach((child,index)=>{
               barArray.push(child.props);
            })
        return barArray;
  }

  // shouldComponentUpdate(){
  //     if(nextProps.active == this.props.active){
  //         return false;
  //     }
  //     return true;
  // }

  /*
  判断是否是自定义title
   */
  // componentWillMount(){
  //   const children = this.getFormatChildren(this.props.children);
  //   children.forEach((child)=>{
  //     if(child.renderTitleCustom){
  //       this.setState({
  //         customTitle:true
  //       })
  //       return false;
  //     }
  //   })
  // }

  render() {
    const {children,index,navTop,width,height,style,customBar} = this.props;

    const barItem = this.getFormatChildren(children);

    let barStyle = Object.assign({},styles.navBar,style);

    if(!customBar )
      barStyle.width = WIDTH;

    let scollviewStyle = {
      width: 750,
      height:barStyle.height,
      display:'flex',
      flexDirection:'row'
    }
    let contentHeight = height ? height : (WINDOW_HEIGHT - (barStyle.height ? Util.deleteRem(barStyle.height) : 0));
    var barList = this._renderBar(this.state,this.props);
    return (
          <View style={{overflow:'hidden'}} ref="TabSlider">
            {navTop?
            <ScrollView horizontal={true} showScrollbar={false} style={scollviewStyle} showsHorizontalScrollIndicator={false}>
                { barList }
            </ScrollView>
              :null
            }
            <Slider ref="Slider" width={width} height={contentHeight}
                      autoplay={false}
                      index = {index}
                      showsPagination={false}
                      loop="false"
                      autoplayTimeout="3000"
                      onChange={this.sliderChange.bind(this)}>
              { this._renderPane(this.getFormatChildren(children)) }
            </Slider>
            {!navTop?
              <View style={barStyle}>
                  <ScrollView horizontal={true} showScrollbar={false} style={scollviewStyle} showsHorizontalScrollIndicator={false}>
                      { barList }
                  </ScrollView>
              </View>:null
            }
          </View>
      )
    }
}
TabSlider.propTypes = {
    active:PropTypes.active,
    navTop:PropTypes.boolean,
    width:PropTypes.number,
    height:PropTypes.number,
    customBar:PropTypes.boolean
}

TabSlider.defaultProps = {
    active:0,
    navTop:false,
    width:750,
    height:null,
    customBar:false
};

TabSlider.Pane  = Pane;

export default TabSlider;
