# Tabbar Item 自定义渲染

- order: 1

可任意渲染 item 的 dom 结构

-----------

````js

/** @jsx createElement */
import {createElement, Component,render} from 'rax';
import View from 'nuke-view';
import Text from 'nuke-text';
import Image from 'nuke-image';
import Touchable from 'nuke-touchable';
import Tabbar from 'nuke-tabbar';
import Page from 'nuke-page';
import Icon from 'nuke-icon';
import Iconfont from 'nuke-iconfont';

const iconsMap = {
    tab1:{
        icon:'\ue650',
        name:'标题一'
    },
    tab2:{
        icon:'\ue631',
        name:'标题二'
    },
    tab3:{
        icon:'\ue65e',
        name:'标题三'
    },
    tab4:{
        icon:'\ue65d',
        name:'标题四'
    }
}
let App = class NukeDemoIndex extends Component {
    constructor() {
        super();
        Iconfont({name:"tabicons",url:"https://at.alicdn.com/t/font_jw65w2xs3tm7k3xr.ttf"});
        this.state =  {
            activeKey: {key: 'tab1'}
        };
    }

    renderContent = (pageText) => {
        return (
          <View style={[styles.tabContent]}>
            <Text style={styles.tabText}>{pageText}</Text>
          </View>
        );
    }
    renderItem = (Name,isActive, key) =>{
        return (<View style={styles.item}>
            <Text style={[styles.itemText,isActive ? styles.activeText:{}]}>{Name}</Text>
        </View>);
    }
    renderItemCapsule = (Name,isActive, key) =>{
        return (<View style={styles.itemCapsule}>
            <Text style={[styles.itemTextCapsule,isActive ? styles.activeTextCapsule:{}]}>{Name}</Text>
        </View>);
    }
    renderItemWithIcon = (iconName,isActive, key) =>{
        return (<View style={styles.item}>
            <View style={[styles.itemIcon, isActive ? styles.itemIconActiveBg : {}]}>
                <Text style={[styles.icon,isActive ? styles.activeTextWithIcon:{}]}>{iconsMap[iconName]['icon']}</Text>
            </View>
            <Text style={[styles.itemText,isActive ? styles.activeText:{}]}>{iconsMap[iconName]['name']}</Text>
        </View>);
    }
    renderItemScrollable = (Name,isActive, key) =>{
        return (<View style={styles.itemFixWidth}>
            <Text style={[styles.itemText,isActive ? styles.activeText:{}]}>{Name}</Text>
        </View>);
    }

    render() {
        return (
            <Page title="Tabbar">

                <Page.Intro main="顶部" sub="包含内容"></Page.Intro>
                <View style={styles.tabWithContent}>
                    <Tabbar navTop={true} navStyle={{active: styles.activeBorder, inactive: styles.inactiveBorder}} activeKey={this.state.activeKey} itemStyle={{height:'70rem'}}>
                        <Tabbar.Item
                            tabKey="tab1"
                            style={styles.item}
                            render={this.renderItem.bind(this,'标题一')}>
                            {this.renderContent('tab1')}
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab2"
                            render={this.renderItem.bind(this,'标题二')}>
                            {this.renderContent('tab2')}
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab3"
                            render={this.renderItem.bind(this,'标题三')}>
                            {this.renderContent('tab3')}
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab4"
                            render={this.renderItem.bind(this,'标题四')}>
                            {this.renderContent('tab4')}
                        </Tabbar.Item>
                    </Tabbar>
                </View>
                <Page.Intro sub="仅tab"></Page.Intro>
                <View style={styles.tabWithoutContent}>
                    <Tabbar navTop={true} navStyle={{active: styles.activeBorder, inactive: styles.inactiveBorder}} activeKey={this.state.activeKey}>
                        <Tabbar.Item
                            tabKey="tab1"
                            render={this.renderItem.bind(this,'标题一')}>
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab2"
                            render={this.renderItem.bind(this,'标题二')}>
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab3"
                            render={this.renderItem.bind(this,'标题三')}>
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab4"
                            render={this.renderItem.bind(this,'标题四')}>
                        </Tabbar.Item>
                    </Tabbar>
                </View>
                <Page.Intro sub="可滚动"></Page.Intro>
                <View style={styles.tabWithContent}>
                    <Tabbar navTop={true} navScrollable={true} navStyle={{active: styles.activeBorder, inactive: styles.inactiveBorder}} activeKey={this.state.activeKey}>
                        <Tabbar.Item tabKey="tab1"
                            render={this.renderItemScrollable.bind(this,'全部订单')}>
                            {this.renderContent('全部订单')}
                        </Tabbar.Item>
                        <Tabbar.Item tabKey="tab2"
                            render={this.renderItemScrollable.bind(this,'7天')}>
                            {this.renderContent('7天')}
                        </Tabbar.Item>
                        <Tabbar.Item tabKey="tab3"
                            render={this.renderItemScrollable.bind(this,'30天')}>
                            {this.renderContent('30天')}
                        </Tabbar.Item>
                        <Tabbar.Item tabKey="tab4"
                            render={this.renderItemScrollable.bind(this,'退款')}>
                            {this.renderContent('退款')}
                        </Tabbar.Item>
                        <Tabbar.Item tabKey="tab5"
                            render={this.renderItemScrollable.bind(this,'未发货')}>
                            {this.renderContent('未发货')}
                        </Tabbar.Item>
                        <Tabbar.Item tabKey="tab6"
                            render={this.renderItemScrollable.bind(this,'部分发货')}>
                            {this.renderContent('部分发货')}
                        </Tabbar.Item>
                    </Tabbar>
                </View>
                <Page.Intro main="底部带icon" sub="icon"></Page.Intro>
                <View style={styles.tabWithContent}>
                    <Tabbar iconBar={true} activeKey={this.state.activeKey}>
                        <Tabbar.Item
                            tabKey="tab1"
                            render={this.renderItemWithIcon.bind(this,'tab1')}>
                            {this.renderContent('tab1')}
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab2"
                            render={this.renderItemWithIcon.bind(this,'tab2')}>
                            {this.renderContent('tab2')}
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="tab3"
                            render={this.renderItemWithIcon.bind(this,'tab3')}>
                            {this.renderContent('tab3')}
                        </Tabbar.Item>
                        
                    </Tabbar>
                </View>
                
                <Page.Intro main="Slider模式" sub="如果非全屏独占，必须手动声明高度"></Page.Intro>
                <View style={styles.tabWithContent}>
                    <Tabbar slider={true} style={{height:'400rem'}} iconBar={true} activeKey={{key: '0'}}>
                        <Tabbar.Item
                            tabKey="0"
                            render={this.renderItemWithIcon.bind(this,'tab1')}
                            >
                            {this.renderContent('tab1')}
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="1"
                            render={this.renderItemWithIcon.bind(this,'tab2')}
                            >
                            {this.renderContent('tab2')}
                        </Tabbar.Item>
                        <Tabbar.Item
                            tabKey="2"
                            render={this.renderItemWithIcon.bind(this,'tab3')}
                            >
                            {this.renderContent('tab3')}
                        </Tabbar.Item>
                        
                        
                    </Tabbar>
                </View>
            </Page>
        );
    }
}
const styles = {
    tabWithContent: {
        marginTop:'20rem',
        height:'400rem'
    },
    tabWithoutContent: {
        marginTop:'20rem',
        height:'200rem'
    },
    tabContent:{
        flex:1,
        backgroundColor:'#ffffff',
        alignItems: 'center',
        justifyContent:'center'
    },
    tabText: {
        fontSize:'40rem'
    },
    item:{
        height:'70rem',
        alignItems: 'center',
        justifyContent:'center'
    },
    icon:{
        fontFamily: 'tabicons',
        fontSize:'32rem',
        color:'#999999'
    },
    itemFixWidth:{
        width:'150rem',
        alignItems: 'center',
        justifyContent:'center'
    },
    itemIcon:{
        width:'48rem',
        height:'48rem',
        borderRadius:'24rem',
        marginBottom:'6rem',
        marginTop:'14rem',
        alignItems: 'center',
        justifyContent:'center'
    },
    activeText:{
        color:'#3089dc'
    },
    activeTextWithIcon:{
        color:'#ffffff'
    },

    itemIconActiveBg:{
        backgroundColor:'#3089dc',
    },
    itemCapsule:{
        alignItems: 'center',
        justifyContent:'center',
        width:'150rem',
    },
    itemTextCapsule:{
        color:'#3089dc',
        fontSize:'32rem'
    },
    activeTextCapsule:{
        color:'#ffffff'
    },
}


render(<App/>);
````
