/** @jsx createElement */

/**
 * Copyright (c) 2015-present, Alibaba Group Holding Limited.
 * All rights reserved.
 *
 * usage:
 * Transition(box, {translate(150,150)}, {
 *          timingFunction: 'linear',
 *          delay: 0,
 *          duration: 500
 *       }, function() {
 *           cb && cb.call(this);
 *       });
 */
'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _nukeEnv = require('nuke-env');

var _nukeEnv2 = _interopRequireDefault(_nukeEnv);

var _tran = require('./tran');

var _tran2 = _interopRequireDefault(_tran);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isWeex = _nukeEnv2.default.isWeex,
    isWeb = _nukeEnv2.default.isWeb;

function getDefaultRem() {
	return document.documentElement.clientWidth / 750;
}
function parseRem(val) {
	var regArr = {
		translateX: 'translateX\\((\[-\+\]\?\\w\+)\\)',
		translateY: 'translateY\\((\[-\+\]\?\\w\+)\\)',
		translate: 'translate\\((\[-\+\]\?\\w\+)\\,(\[-\+\]\?\\w\+)\\)'
	};

	for (var p in regArr) {
		var reg = new RegExp(regArr[p]);
		if (val.match(reg)) {
			if (p === 'translateX' || p === 'translateY') {
				var matchArr = val.match(reg);
				var num = +matchArr[1];
				val = val.replace(matchArr[1], num * getDefaultRem() + 'px');
			} else {
				var matchArr = val.match(reg);
				var x = +matchArr[1];
				var y = +matchArr[2];
				val = 'translate(' + x * getDefaultRem() + 'px,' + y * getDefaultRem() + 'px)';
			}
		}
	}

	return val;
}
function Trans(node, styles, options, callback) {
	if (isWeb) {
		//rem to px
		for (var key in styles) {
			if (key === 'transform') {
				styles[key] = parseRem(styles[key]);
			} else if (arrayContains(key, ['top', 'left', 'height', 'bottom', 'right', 'width'])) {
				var matchArr = styles[key].match(/(\d+)(rem){0,1}/);
				styles[key] = styles[key].replace(matchArr[0], matchArr[1] * getDefaultRem() + 'px');
			}
		}
		(0, _tran2.default)(node, styles, options, callback);
	} else {
		(0, _tran2.default)(node, styles, options, callback);
	}
}

function arrayContains(value, arr) {
	for (var i = 0; i < arr.length; i++) {
		if (value === arr[i]) {
			return true;
		}
	}
	return false;
}
exports.default = Trans;
module.exports = exports['default'];