/** @jsx createElement */
import {createElement, Component,render} from 'rax';
import View from 'nuke-view';
import Text from 'nuke-text';
import Page from 'nuke-page';
import Navigator from 'nuke-navigator';
import Button from 'nuke-button';
import Util from 'nuke-util';
const {urlHandler, urlHelper,Location} = Util;


const urlKeys = ['protocol','hostname','pathname','port','host','search','hash'];

const originUrl1 = 'https://www.taobao.com?_wx_tpl=https://30.5.96.241:3000/docs/basic.js?id=76843';
const qnUrl1 = 'qap://mods/advanced.js?advancedIndex=2003341245&status=5';

const originUrl2 = 'https://g.alicdn.com/nuke/tabbar/0.3.4/basic.html';
const qnUrl2 = 'qap://pages/deep/new.js?type=245';

const originUrl3 = 'https://isvdomain.com/plugina/orders/orderlist.html';
const qnUrl3 = 'qap://settings/index.js';

const originUrl4 = 'https://isvdomain.com/plugina/sms/index.html?aaa=dd&isqap=true';
const qnUrl4 = 'qap://settings/index.js';

let weexUrlObj1 = urlHelper.urlParse(originUrl1);
let qnUrlObj1 = urlHelper.urlParse(qnUrl1);

let transferResult1 = urlHandler(qnUrl1,{
    refer : originUrl1
});

let transferResult2 = urlHandler(qnUrl2,{

    refer : originUrl2
});

let transferResult3 = urlHandler(qnUrl3,{
    refer : originUrl3,
    webRootPath : 'https://isvdomain.com/plugina/'
});

let transferResult4 = urlHandler(qnUrl4,{
    refer : originUrl4,
    webRootPath:'https://isvdomain.com/pluginbbb/',
    contextQuery:'isqap=true'
});

let App = class NukeDemoIndex extends Component {
    constructor() {
        super();
    }
    getStandardOutput(urlObj){
        let result = [];
        urlKeys.forEach((item)=>{
            result.push(
                <View style={styles.resultItem}>
                    <Text style={styles.key}>{item}</Text>
                    <Text style={styles.val}>{urlObj[item]}</Text>
                </View>
            )
        })
        return result;
    }
    
    render() {
        return (
            <Page title="Util">
                <Page.Intro main="Location"></Page.Intro>
                <View style={styles.original}><Text style={styles.originalText}>{JSON.stringify(Location)}}</Text></View>
                <Page.Intro main="urlHelper" sub="urlParse"></Page.Intro>
                <View style={styles.original}><Text style={styles.originalText}>{originUrl1}</Text></View>
                <View style={styles.result}>
                    {this.getStandardOutput(weexUrlObj1)}
                </View>
                <View style={styles.original}><Text style={styles.originalText}>{qnUrl1}</Text></View>
                <View style={styles.result}>
                    {this.getStandardOutput(qnUrlObj1)}
                </View>

                <Page.Intro main="路径转换" sub="链接到下个页面时"></Page.Intro>
                <View style={styles.originalLabel}><Text style={styles.originalText}>从</Text></View>
                <View style={styles.originalFrom}><Text style={styles.originalText}>{originUrl1}</Text></View>
                <View style={styles.originalLabel}><Text style={styles.originalText}>链接到</Text></View>
                <View style={styles.originalTo}><Text style={styles.originalText}>{qnUrl1}</Text></View>
                <View style={styles.resultChange}>
                    <Text style={styles.resultChangeText}>{transferResult1}</Text>
                </View>
                <View style={styles.originalLabel}><Text style={styles.originalText}>从</Text></View>
                <View style={styles.originalFrom}><Text style={styles.originalText}>{originUrl2}</Text></View>
                <View style={styles.originalLabel}><Text style={styles.originalText}>链接到</Text></View>
                <View style={styles.originalTo}><Text style={styles.originalText}>{qnUrl2}</Text></View>
                <View style={styles.resultChange}>
                    <Text style={styles.resultChangeText}>{transferResult2}</Text>
                </View>

                <View style={styles.originalLabel}><Text style={styles.originalText}>从</Text></View>
                <View style={styles.originalFrom}><Text style={styles.originalText}>{originUrl3}</Text></View>
                <View style={styles.originalLabel}><Text style={styles.originalText}>链接到</Text></View>
                <View style={styles.originalTo}><Text style={styles.originalText}>{qnUrl3}</Text></View>

                <View style={styles.originalLabel}><Text style={styles.originalText}>且webRootPath https://isvdomain.com/plugina/</Text></View>

                <View style={styles.resultChange}>
                    <Text style={styles.resultChangeText}>{transferResult3}</Text>
                </View>

                <View style={styles.originalLabel}><Text style={styles.originalText}>从</Text></View>
                <View style={styles.originalFrom}><Text style={styles.originalText}>{originUrl4}</Text></View>
                <View style={styles.originalLabel}><Text style={styles.originalText}>链接到</Text></View>
                <View style={styles.originalTo}><Text style={styles.originalText}>{qnUrl4}</Text></View>
                <View style={styles.originalLabel}><Text style={styles.originalText}>且webRootPath https://isvdomain.com/pluginbbb/</Text></View>
                <View style={styles.originalLabel}><Text style={styles.originalText}>且持续传参 isqap = true</Text></View>
                <View style={styles.resultChange}>
                    <Text style={styles.resultChangeText}>{transferResult4}</Text>
                </View>

                
            </Page>

        );
    }
}

const styles = {
    original:{
        
        flexDirection:'row',
        backgroundColor:'#DAEEFF',
        width:'690rem',
        borderLeftWidth:'6rem',
        borderLeftStyle:'solid',
        borderLeftColor:'#3089dc',
        marginLeft:'30rem',
        marginTop:'30rem',
        padding:'20rem'
        
    },
    originalLabel:{
        paddingLeft:'40rem',
        marginTop:'10rem',
    },
    originalFrom:{
        
        flexDirection:'row',
        backgroundColor:'#FFF1E8',
        width:'690rem',
        borderLeftWidth:'6rem',
        borderLeftStyle:'solid',
        borderLeftColor:'#EB7E10',
        marginLeft:'30rem',
        marginTop:'10rem',
        padding:'10rem'
        
    },
    originalTo:{
        
        flexDirection:'row',
        backgroundColor:'#DAEEFF',
        width:'690rem',
        borderLeftWidth:'6rem',
        borderLeftStyle:'solid',
        borderLeftColor:'#3089dc',
        marginLeft:'30rem',
        marginTop:'10rem',
        padding:'10rem'
        
    },
    originalText:{
        lines:3,
        flex:1,
        wordBreak: 'break-all',//for web
        lineHeight:'36rem',
        textOverflow:'ellipsis'
    },
    result:{
        padding:'30rem',

    },
    resultChange:{
        backgroundColor:'#ffffff',
        marginLeft:'30rem',
        marginRight:'30rem',
        marginBottom:'50rem',
        padding:'10rem',
    },
    resultChangeText:{
        fontSize:'28rem',
        wordBreak:'break-all',
        lines:3,
        textOverflow:'ellipsis',
    },
    resultItem:{
        flexDirection:'row',
        backgroundColor:'#ffffff',
        borderBottomWidth:'1rem',
        borderBottomStyle:'solid',
        borderBottomColor:'#dddddd',
    },
    key:{
        width:'220rem',
        paddingLeft:'20rem',
        lineHeight:'48rem',
        color:'#666666'
    },
    val:{
        flex:1,
        lineHeight:'48rem',
        lines:4,
        fontSize:'28rem',
        paddingTop:'1rem',
        textOverflow:'ellipsis',
        wordBreak: 'break-all',//for web
    }
}
render(<App/>);