'use strict';

var path = require('path');
var fs = require('fs');
var jsonfile = require('jsonfile');
jsonfile.spaces = 4;

var ROOT = path.join(__dirname, '..');
var SOURCE = path.join(ROOT, 'src');
var TARGET = ROOT;
var PATTERN_NEXT = /^nuke\-([^\/]+)(.*)$/;
var PATTERN_NODE_MODULES = /^node_modules/;
var NEXT_CORE = 'nuke-core';
var pkg = require(path.join(ROOT, 'package.json'));
var variables = {};
var addons = {
    'index.js': '',
    'lib/index.js': ''
};
var core_addons = [];

module.exports = {
    source: SOURCE,

    target: {
        path: TARGET
        // redirect: function(relative) {
        //     const srcRelative = relative;
        //     relative = relative.replace(PATTERN_NODE_MODULES, 'lib/');
        //     return relative;
        // },
    },
    writeBack: true, //是否回写dependency
    // exclude: Object.keys(pkg.devDependencies || {}),
    exclude: function exclude(id) {
        return !PATTERN_NEXT.test(id);
    },

    extensions: {
        js: ['', '.jsx', '.js'],
        css: ['.scss', '.css'],
        html: ['.html', '.htm', '.tpl']
    },

    clear: ['lib', 'docs', 'demos', 'index.js', 'components.scss'].map(function (f) {
        return path.join(TARGET, f);
    }),

    modules: [{
        match: PATTERN_NEXT,
        main: ['lib/index.js', 'lib/index.jsx', 'lib/index.scss'],
        docs: {
            'README.md': {
                target: function target(pathname, entry) {
                    return 'docs/' + entry.name.replace(PATTERN_NEXT, '$1') + '/index.md';
                }
            },
            'docs/*.md': {
                target: function target(pathname, entry) {
                    return 'docs/' + entry.name.replace(PATTERN_NEXT, '$1') + '/demo/' + path.basename(pathname);
                },
                resolve: function resolve(id, entry) {
                    return id;
                },
                combine: function combine(id, name) {
                    if (PATTERN_NEXT.test(id)) {
                        var cname = varCase(RegExp.$1);
                        if (cname == 'Mounter' || cname == 'Components') {
                            return null;
                        }
                        return {
                            name: cname,
                            group: 'nuke'
                        };
                    }
                    return null;
                }
            }
        },
        theme: {
            main: 'theme/index.jsx',
            entryName: function entryName(pathname, entry) {
                return 'demos/' + entry.name.replace(PATTERN_NEXT, '$1');
            },
            deps: function deps(pathname, entry) {
                var pkg = require(path.join(entry.context, 'package.json'));

                return Object.keys(pkg.devDependencies || {}).filter(function (name) {
                    return PATTERN_NEXT.test(name) && name !== '@alife/next-demo-helper';
                }).map(function (name) {
                    return name.replace(PATTERN_NEXT, '$1');
                });
            }
        }

    }],

    listeners: {
        //调整lib目录结构
        'transformed': function transformed(pathname, name) {
            var key = name.replace(PATTERN_NEXT, '$1');
            var nPath = 'lib/' + varCase(key) + '.js';
            if (name === NEXT_CORE) {
                core_addons.push(pathname);
                // if (pathname.indexOf('next.scss') !== -1 || pathname.indexOf('index.scss')) {
                //     //addons['components.scss'] = `@import "${getRelative('index.scss', pathname)}";\n` + addons['components.scss'];
                // }
            } else {
                //原件等特殊组件需暴露出更多变量，应该尽量避免这种写法，组件的职责需要单一。
                if (key == 'components') {
                    var files = fs.readdirSync(pathname.split('index.js')[0]);
                    files.forEach(function (filename) {
                        filename = filename.split('.js')[0];
                        if (varCase(filename) !== 'Link' && varCase(filename) !== 'Index') {
                            var tempIndexPath = './src/node_modules/' + name + '/lib/' + filename + '.js';
                            var relativeIndexPath = name + '/lib/' + filename + '.js';
                            addons['index.js'] += 'module.exports.' + varCase(filename) + ' = require(\'' + tempIndexPath + '\');\n';
                            addons['lib/index.js'] += 'module.exports.' + varCase(filename) + ' = require(\'' + relativeIndexPath + '\');\n';
                            fs.writeFileSync(path.join(TARGET, 'lib/' + varCase(filename) + '.js'), 'module.exports = require(\'' + name + '/lib/' + filename + '.js\');\n');
                        }
                    });
                } else if (key == 'layout') {
                    addons['index.js'] += 'module.exports.Layout = require(\'./src/node_modules/' + name + '/lib/index.js\');\n';
                    var files = fs.readdirSync(pathname.split('index.js')[0] + 'mods');
                    files.forEach(function (filename) {
                        var tempIndexPath = './src/node_modules/' + name + '/lib/mods/' + filename;
                        var relativeIndexPath = name + '/lib/mods/' + filename;
                        addons['index.js'] += 'module.exports.' + varCase(filename.split('.js')[0]) + ' = require(\'' + tempIndexPath + '\');\n';
                        addons['lib/index.js'] += 'module.exports.' + varCase(filename.split('.js')[0]) + ' = require(\'' + relativeIndexPath + '\');\n';
                        fs.writeFileSync(path.join(TARGET, 'lib/' + varCase(filename)), 'module.exports = require(\'' + name + '/lib/mods/' + filename + '\');\n');
                    });
                } else {
                    var tempIndexPath = './src/node_modules/' + name;
                    var relativeIndexPath = '' + name;
                    addons['index.js'] += 'module.exports.' + varCase(key) + ' = require(\'' + tempIndexPath + '\');\n';
                    addons['lib/index.js'] += 'module.exports.' + varCase(key) + ' = require(\'' + relativeIndexPath + '\');\n';
                }
            }
            var libPath = path.join(TARGET, 'lib');
            if (!fs.existsSync(libPath)) {
                fs.mkdirSync(libPath);
            }
            if (key !== 'layout') fs.writeFileSync(path.join(TARGET, nPath), 'module.exports = require(\'' + name + '\');\n');
        },
        //输出index.js引用
        'outputed': function outputed() {
            // write addons(root, entry)
            for (var relative in addons) {
                var target = path.join(TARGET, relative);
                // make sure dir is exists
                if (!fs.existsSync(path.dirname(target))) {
                    fs.mkdirSync(path.dirname(target));
                }
                fs.writeFileSync(target, new Buffer(addons[relative]));
            }
            // write variables.json
            // wirte package.json
            try {
                var dependencies = jsonfile.readFileSync(path.join(ROOT, 'src/package.json')).dependencies;
                var rootPkg = jsonfile.readFileSync(path.join(ROOT, 'package.json'));
                rootPkg.dependencies = dependencies;
                jsonfile.writeFileSync(path.join(ROOT, 'package.json'), rootPkg);
            } catch (e) {
                console.log('写入根目录package.json失败，请勿发布');
            }
        }
    },
    notice: {
        'dingtalk': ['https://oapi.dingtalk.com/robot/send?access_token=c3b58ba1754c6922df4dee6f5d80569ff1127fd237c9252bf59378f8e5fee5db']
    },
    switchs: {
        buildDemo: false, //是否构建demo--用于配置平台
        sassCheck: false, //是否进行sass-check--qnui非必须
        compatibility: { //兼容性基线版本设置
            qn: { ios: '5.8.0', android: '5.8.1', describe: {} },
            tb: { ios: '6.4.1', android: '6.4.1', describe: {} },
            tm: { ios: '5.28.2', android: '5.28.2', describe: {} }
        }
    }
};

function getRelative(from, to, isJS) {
    var relative = path.relative(path.dirname(from), to).replace(/\\/g, '/');

    return isJS ? relative[0] === '.' ? relative : './' + relative : relative;
}

/*
 * abc-xyz -> AbcXyz
 */
function varCase(str) {
    var result = [];

    for (var i = 0, l = str.length; i < l; i++) {
        var c = str[i];

        if (c === '-') {
            result.push(str[i + 1].toUpperCase());
            i++;
            continue;
        }

        result.push(c.toLowerCase());
    }

    if (result[0]) {
        result[0] = result[0].toUpperCase();
    }

    return result.join('');
}