'use strict';

const path = require('path');
const fs = require('fs');
const extraFS = require('fs-extra');
var jsonfile = require('jsonfile');
jsonfile.spaces = 4;

const ROOT = path.join(__dirname, '..');
const SOURCE = path.join(ROOT, 'src');
const TARGET = ROOT;
const PATTERN_NEXT = /^nuke\-([^\/]+)(.*)$/;
const PATTERN_NODE_MODULES = /^node_modules/;
const NEXT_CORE = 'nuke-core';
const pkg = require(path.join(ROOT, 'package.json'));
const variables = {};
const addons = {
  'index.js': ''
};
let core_addons = [];

module.exports = {
  source: SOURCE,

  target: {
    path: TARGET,
    redirect: function(relative) {
      const srcRelative = relative;
      relative = relative.replace(PATTERN_NODE_MODULES, 'lib/_components');
      if (relative.indexOf('/node_modules/') !== -1) {
        throw new Error('请解决小包中的版本冲突！\n' + srcRelative);
      }
      return relative;
    }
  },
  writeBack: true, //是否回写dependency,在新增组件时需注意无法回写首次添加的依赖【bug】
  // exclude: Object.keys(pkg.devDependencies || {}),
  exclude: id => !PATTERN_NEXT.test(id),

  extensions: {
    js: ['', '.jsx', '.js'],
    css: ['.scss', '.css'],
    html: ['.html', '.htm', '.tpl']
  },

  clear: ['lib', 'docs', 'demos', 'index.js', 'components.scss', 'dist'].map(
    f => path.join(TARGET, f)
  ),

  modules: [
    {
      match: PATTERN_NEXT,
      main: ['lib/index.js', 'lib/index.jsx', 'lib/index.scss'],
      docs: {
        'README.md': {
          target: (pathname, entry) => {
            return `docs/${entry.name.replace(PATTERN_NEXT, '$1')}/index.md`;
          }
        },
        'docs/*.md': {
          target: (pathname, entry) => {
            return `docs/${entry.name.replace(
              PATTERN_NEXT,
              '$1'
            )}/demo/${path.basename(pathname)}`;
          },
          resolve: (id, entry) => {
            return id;
          },
          combine: (id, name) => {
            if (PATTERN_NEXT.test(id)) {
              let cname = varCase(RegExp.$1);
              if (cname == 'Mounter' || cname == 'Components') {
                return null;
              }
              return {
                name: cname,
                group: 'nuke'
              };
            }
            return null;
          }
        }
      },
      theme: {
        main: 'theme/index.jsx',
        entryName: (pathname, entry) => {
          return `demos/${entry.name.replace(PATTERN_NEXT, '$1')}`;
        },
        deps: (pathname, entry) => {
          const pkg = require(path.join(entry.context, 'package.json'));

          return Object.keys(pkg.devDependencies || {})
            .filter(
              name =>
                PATTERN_NEXT.test(name) && name !== '@alife/next-demo-helper'
            )
            .map(name => name.replace(PATTERN_NEXT, '$1'));
        }
      }
    }
  ],

  listeners: {
    //调整lib目录结构
    transformed: (pathname, name) => {
      const key = name.replace(PATTERN_NEXT, '$1');
      const nPath =
        'lib/' + varCase(name.replace(PATTERN_NEXT, '$1')) + '/index';
      if (name === NEXT_CORE) {
        core_addons.push(pathname);
      } else {
        let relative;
        let rRelative;
        relative = getRelative(path.join(TARGET, nPath), pathname, true);
        rRelative = getRelative(path.join(TARGET, 'index'), pathname, true);
        addons[nPath + '.js'] = `module.exports = require('${relative}');`;
        //   addons['lib/index.js'] += `module.exports.${varCase(key)} = require('${rRelative}');\n`;
        addons['index.js'] += `module.exports.${varCase(
          key
        )} = require('${rRelative}');\n`;

        if (key == 'components') {
          // var srcPath = path.join(TARGET,'src/node_modules/nuke-components/lib');
          // var files = fs.readdirSync(srcPath);
          //   files.forEach((filename)=>{
          //      let rePath = 'lib/' + varCase(filename.replace('.js','')) + '/index';
          //      if(filename!=='Link.js' && filename!=='index.js'){
          //          var comPath = 'lib/' + varCase(key) + `/${filename}`;
          //          comPath = getRelative(path.join(TARGET, comPath), pathname.replace('index.js',filename), true);
          //          var tempIndexPath = getRelative(__dirname, pathname.replace('index.js',filename),true);
          //          filename = filename.replace('.js','');
          //          addons[rePath + '.js'] = `module.exports = require('${comPath}');\n`;
          //       //    addons['lib/index.js'] += `module.exports.${varCase(filename)} = require('${comPath}');\n`;
          //          addons['index.js'] += `module.exports.${varCase(filename)} = require('${tempIndexPath}');\n`;
          //      }
          //  })
        } else if (key == 'layout') {
          var srcPath = path.join(
            TARGET,
            'src/node_modules/nuke-layout/lib/mods'
          );
          var files = fs.readdirSync(srcPath);
          files.forEach(filename => {
            let rePath =
              'lib/' + varCase(filename.replace('.js', '')) + '/index';
            var comPath = 'lib/' + varCase(key) + `/${filename}`;
            comPath = getRelative(
              path.join(TARGET, comPath),
              pathname.replace('index.js', 'mods/' + filename),
              true
            );
            var tempIndexPath = getRelative(
              __dirname,
              pathname.replace('index.js', 'mods/' + filename),
              true
            );
            filename = filename.replace('.js', '');
            addons[
              rePath + '.js'
            ] = `module.exports = require('${comPath}');\n`;
            //  addons['lib/index.js'] += `module.exports.${varCase(filename)} = require('${comPath}');\n`;
            addons['index.js'] += `module.exports.${varCase(
              filename
            )} = require('${tempIndexPath}');\n`;
          });
        }
      }
    },
    //输出index.js引用
    outputed: () => {
      // write addons(root, entry)
      for (let relative in addons) {
        let target = path.join(TARGET, relative);
        // make sure dir is exists
        if (!fs.existsSync(path.dirname(target))) {
          fs.mkdirSync(path.dirname(target));
        }
        fs.writeFileSync(target, new Buffer(addons[relative]));
      }
      // try {
      //   extraFS.copySync('/tmp/myfile', '/tmp/mynewfile')
      //   console.log("success!")
      // } catch (err) {
      //   console.error(err)
      // }
    }
  },
  notice: {
    dingtalk: [
      'https://oapi.dingtalk.com/robot/send?access_token=77c5ef329df0b4c04e7329fef8278435a82edfc74553e150ac665f914d39439a'
    ]
  },
  switchs: {
    buildDemo: false, //是否构建demo--用于配置平台
    sassCheck: false, //是否进行sass-check--qnui非必须
    compatibility: {
      //兼容性基线版本设置
      qn: { ios: '5.8.2', android: '5.8.2', describe: {} },
      tb: { ios: '6.4.1', android: '6.4.1', describe: {} },
      tm: { ios: '5.28.2', android: '5.28.2', describe: {} }
    }
  }
};

function getRelative(from, to, isJS) {
  const relative = path.relative(path.dirname(from), to).replace(/\\/g, '/');

  return isJS ? (relative[0] === '.' ? relative : './' + relative) : relative;
}

/*
 * abc-xyz -> AbcXyz
 */
function varCase(str) {
  let result = [];

  for (let i = 0, l = str.length; i < l; i++) {
    let c = str[i];

    if (c === '-') {
      result.push(str[i + 1].toUpperCase());
      i++;
      continue;
    }

    result.push(c.toLowerCase());
  }

  if (result[0]) {
    result[0] = result[0].toUpperCase();
  }

  return result.join('');
}
